// ----------------------------------------------------------------------------
// This component handles dynamic loading of the Composer Module component(s)
// ----------------------------------------------------------------------------
ComposerTemplate01 = new Class(
{
	Extends : ProductComposer,
	
	// ************************************************************************
	// ************************************************************************
	//     LIST OF COMPONENT ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************
	
	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	hasSkinCoreAsset : function(){return true;},
	hasSkinLangAsset : function(){return false;},

	// ------------------------------------------------------------------------
	// These functions return the list of plug-in assets to dynamically load for this component
	// ------------------------------------------------------------------------
	listJavascriptAssets : function(){return [];},
	listCssAssets : function(){return [BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'components/generic/ComposerTemplate01/ComposerTemplate01.css'];},
	// ************************************************************************
	// ************************************************************************
	//     MEMBER VARIABLES
	// ************************************************************************
	// ************************************************************************	


	// ************************************************************************
	// ************************************************************************
	//     PROXY FUNCTIONS
	// ************************************************************************
	// ************************************************************************	
	
	// ------------------------------------------------------------------------
	// This is a proxy for the UIMediator listNotificationInterests function.
	// 
	// This function returns the list of notifications to register this view for.
	//
	// @return {String[]} - the array of notification names to act upon.
	// ------------------------------------------------------------------------
	listNotificationInterests : function()
	{
		var theArray = this.parent().append
		(
			[
			]
		);
        return theArray;
	},
	
	// ------------------------------------------------------------------------
	// This is a proxy for the UIMediator handleNotification function.
	//
	// This function is called to handle all notifications listed in the 
	// listNotificationInterests function
	//
	// Arguments:
	//     notification (Notification) - The notification to act upon
	// ------------------------------------------------------------------------
	handleNotification : function(notification)
	{
		switch(notification.getName())
		{
			default:
				this.parent(notification);
				break;
		}
	},

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR FUNCTIONS
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('ComposerTemplate01', this);
	},
	
	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theComponentData (Object) - Contains the ProductList array
	// ------------------------------------------------------------------------
	init : function(theBasePath, theComponentData)
    {
		this.parent(theBasePath, theComponentData);
	},
	
	// ------------------------------------------------------------------------
	// The javascript assets are loaded by the time this function is
	// called so here instantiate and init them.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{
		this.parent();
	},
	
	// ************************************************************************
	// ************************************************************************
	//     PUBLIC FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	getPageWidth : function()
	{
		return 750;
	},
	
	getPageHeight : function()
	{
		return 850;
	},
	
	getPageCount : function()
	{
		return Math.floor((this._productCount+2)/3);
	},
	
	// ------------------------------------------------------------------------
	// Get product range request object used to retrieve the range of products
	// to be displayed on this page. (The product list is retrieved from the database
	// via a call to the ProductCommand.GetProductListRange command.
	// ------------------------------------------------------------------------
	getPageProductRange : function(theBookPageIndex)
	{
		var theProductRange = new Object();
		theProductRange.vendor = Skin.getInstance().get('ProductModuleVendor','dirxion');
		theProductRange.partner = Skin.getInstance().get('ProductModulePartner','');
		theProductRange.key = this._key;
		//theProductRange.categoryId = 'null';
		theProductRange.xStart = theBookPageIndex*3;
		theProductRange.xEnd = theProductRange.xStart+2;
		return theProductRange;
	},
	
	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************
	
	// ------------------------------------------------------------------------
	// Get the html template string used to build the page DOM objects
	// ------------------------------------------------------------------------
	_getPageHtml : function(thePage, thePageProductList)
	{
		var str;
		if (thePage.isLeftPage())
			str = this._getLeftPageHtml(thePage.bookPageIndex, thePageProductList);
		else
			str = this._getRightPageHtml(thePage.bookPageIndex, thePageProductList);
		return str;
	},

	// ------------------------------------------------------------------------
	// ComposerTemplate01 page html for left-side pages
	// ------------------------------------------------------------------------
	_getLeftPageHtml : function(theBookPageIndex, thePageProductList)
	{
		var theItemCount = thePageProductList.length;
		var str = '';
		str += '<div class="template-page template-page-left">';

		str += '	<div class="template-product template-product1" style="display:*DISPLAY*">';
		str += '		<div class="template-product-outline">';
		str += '			<div class="template-product-image-container">';
		str += '				<img class="template-product-image" src="*IMAGE*"></img>';
		str += '			</div>';
		str += '			<div class="template-container-product-content">';
		str += '				<h1 class="template-product-name">*NAME*</h1>';
		str += '				<h2 class="BrandStyle *BRANDSTYLE*">*BRAND*</h2>';
		str += '				<h3>*PRICE*</h3>';
		str += '				<p>*DESCRIPTION*</p>';
		str += '			</div>';
		str += '		</div>';
		str += '	</div>';
			
		str += '	<div class="template-product template-product2" style="display:*DISPLAY*">';
		str += '		<div class="template-product-outline">';
		str += '			<div class="template-product-image-container">';
		str += '				<img class="template-product-image" src="*IMAGE*"></img>';
		str += '			</div>';
		str += '			<div class="template-container-product-content">';
		str += '				<h1 class="template-product-name">*NAME*</h1>';
		str += '				<h2 class="BrandStyle *BRANDSTYLE*">*BRAND*</h2>';
		str += '				<h3>*PRICE*</h3>';
		str += '				<p>*DESCRIPTION*</p>';
		str += '			</div>';
		str += '		</div>';
		str += '	</div>';

		str += '	<div class="template-product template-product3" style="display:*DISPLAY*">';
		str += '		<div class="template-product-outline">';
		str += '			<div class="template-product-image-container">';
		str += '				<img class="template-product-image" src="*IMAGE*"></img>';
		str += '			</div>';
		str += '			<div class="template-container-product-content">';
		str += '				<h1 class="template-product-name">*NAME*</h1>';
		str += '				<h2 class="BrandStyle *BRANDSTYLE*">*BRAND*</h2>';
		str += '				<h3>*PRICE*</h3>';
		str += '				<p>*DESCRIPTION*</p>';
		str += '			</div>';
		str += '		</div>';
		str += '	</div>';

		str += '</div>';

		return str;
	},
	
	// ------------------------------------------------------------------------
	// ComposerTemplate01 page html for right-side pages
	// ------------------------------------------------------------------------
	_getRightPageHtml : function(theBookPageIndex, thePageProductList)
	{
		var theItemCount = thePageProductList.length;
		var str = '';
		str += '<div class="template-page template-page-right">';

		str += '	<div class="template-product template-product1" style="display:*DISPLAY*">';
		str += '		<div class="template-product-outline">';
		str += '			<div class="template-product-image-container">';
		str += '				<img class="template-product-image" src="*IMAGE*"></img>';
		str += '			</div>';
		str += '			<div class="template-container-product-content">';
		str += '				<h1 class="template-product-name">*NAME*</h1>';
		str += '				<h2 class="BrandStyle *BRANDSTYLE*">*BRAND*</h2>';
		str += '				<h3>*PRICE*</h3>';
		str += '				<p>*DESCRIPTION*</p>';
		str += '			</div>';
		str += '		</div>';
		str += '	</div>';

		str += '	<div class="template-product template-product2" style="display:*DISPLAY*">';
		str += '		<div class="template-product-outline">';
		str += '			<div class="template-product-image-container">';
		str += '				<img class="template-product-image" src="*IMAGE*"></img>';
		str += '			</div>';
		str += '			<div class="template-container-product-content">';
		str += '				<h1 class="template-product-name">*NAME*</h1>';
		str += '				<h2 class="BrandStyle *BRANDSTYLE*">*BRAND*</h2>';
		str += '				<h3>*PRICE*</h3>';
		str += '				<p>*DESCRIPTION*</p>';
		str += '			</div>';
		str += '		</div>';
		str += '	</div>';

		str += '	<div class="template-product template-product3" style="display:*DISPLAY*">';
		str += '		<div class="template-product-outline">';
		str += '			<div class="template-product-image-container">';
		str += '				<img class="template-product-image" src="*IMAGE*"></img>';
		str += '			</div>';
		str += '			<div class="template-container-product-content">';
		str += '				<h1 class="template-product-name">*NAME*</h1>';
		str += '				<h2 class="BrandStyle *BRANDSTYLE*">*BRAND*</h2>';
		str += '				<h3>*PRICE*</h3>';
		str += '				<p>*DESCRIPTION*</p>';
		str += '			</div>';
		str += '		</div>';
		str += '	</div>';

		str += '</div>';
		return str;
	},
	
	// ------------------------------------------------------------------------
	// ComposerTemplate01 page layout styles
	// ------------------------------------------------------------------------
	_getCss : function()
	{
		var str = new String('\
		.template-page {\
			width: 750px;\
			height: 850px;\
			background-color: #ffffff;\
		}\
		.template-product {\
			width: 650px;\
			height: 200px;\
			overflow: visible;\
		}\
		.template-page-left .template-product1 .template-product-image-container,\
		.template-page-right .template-product2 .template-product-image-container,\
		.template-page-left .template-product3 .template-product-image-container\
		{\
			position: absolute;\
			top: 0px;\
			left: 0px;\
			right: auto;\
			right: initial;\
			width: 175px;\
			height: 200px;\
			background-color: #ffffff;\
		}\
		.template-page-right .template-product1 .template-product-image-container,\
		.template-page-left .template-product2 .template-product-image-container,\
		.template-page-right .template-product3 .template-product-image-container\
		{\
			position: absolute;\
			top: 0px;\
			left: auto;\
			left: initial;\
			right: 0px;\
			width: 175px; \
			height: 200px;\
			background-color: #ffffff;\
		}\
		.template-product-image {\
			position: absolute;\
			max-height: 100%;\
			max-width: 100%;\
			left: 50%;\
			top: 50%;\
			transform: translateX(-50%) translateY(-50%);\
			-webkit-transform: translateX(-50%) translateY(-50%);\
			-moz-transform: translateX(-50%) translateY(-50%);\
			-ms-transform: translateX(-50%) translateY(-50%);\
		}\
		.template-page-left .template-product1 .template-container-product-content,\
		.template-page-right .template-product2 .template-container-product-content,\
		.template-page-left .template-product3 .template-container-product-content\
		{\
			position: absolute;\
			top: 0px;\
			left: 200px;\
			right: auto;\
			right: initial;\
			width: 450px;\
			height: 200px;\
		}\
		.template-page-right .template-product1 .template-container-product-content,\
		.template-page-left .template-product2 .template-container-product-content,\
		.template-page-right .template-product3 .template-container-product-content\
		{\
			position: absolute;\
			top: 0px;\
			left: auto;\
			left: initial;\
			right: 200px;\
			width: 450px;\
			height: 200px;\
		}\
		.template-container-product-content .template-detail-btn {\
			position: absolute;\
			top: 45px;\
			right: 10px;\
		}\
		.template-page h1 {\
		  font-size: 20px;\
		}\
		.template-page h2 {\
		  font-size: 15px;\
		  margin-top: 10px;\
		}\
		.template-page h3 {\
		  font-size: 15px;\
		  margin-top: 10px;\
		  margin-bottom: 20px;\
		}\
		.template-product1 {\
			position: absolute;\
			top: 50px;\
			left: 50px;\
		}\
		.template-product2 {\
			position: absolute;\
			top: 300px;\
			left: 50px;\
		}\
		.template-product3 {\
			position: absolute;\
			top: 550px;\
			left: 50px;\
		}\
		.template-product-outline {\
			width: 100%;\
			height: 100%;\
		}\
		');
		return str;
	},

	initHotspots : function(thePage)
	{
		thePage.startHotspotInsertions();
		var theProductDomObjs = thePage.toElement().getElements('.template-product');
		theProductDomObjs.each(function(item, index)
		{
			if (item.isVisible())
			{
				var theName = item.getElement('.template-product-outline');
				var theNameSz = theName.measure(function(){return theName.getCoordinates(thePage.toElement());});
				var theXmlStr = '<custom x="*X*" y="*Y*" w="*W*" h="*H*" ><data><name>ProductDetailDlg</name><index>*I*</index></data></custom>';
				theXmlStr = theXmlStr.replace('*X*', theNameSz.left);
				theXmlStr = theXmlStr.replace('*Y*', theNameSz.top);
				theXmlStr = theXmlStr.replace('*W*', theNameSz.width);
				theXmlStr = theXmlStr.replace('*H*', theNameSz.height);
				theXmlStr = theXmlStr.replace('*I*', thePage.bookPageIndex*3 + index);
				var theXmlDoc = jQuery(jQuery.parseXML(theXmlStr)).find("custom").first();
				var theHotspot = new Hotspot();
				theHotspot.initXml(1/thePage._scaleExternal, 1/thePage._scaleExternal, thePage._scaleExternal, theXmlDoc, this._hotspotLayerPolyImageMap, this._hotspotLayerPolyImage);
				thePage.insertHotspot(theHotspot);
			}
		}.bind(this));
		thePage.endHotspotInsertions();
	},
	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});

// ****************************************************************************
// ****************************************************************************
//     Notifications
// ****************************************************************************
// ****************************************************************************

// ****************************************************************************
// ****************************************************************************
//     Constants
// ****************************************************************************
// ****************************************************************************
