// ----------------------------------------------------------------------------
// This View handles the GraingerProtocol custom links
// ----------------------------------------------------------------------------
GraingerProtocol = new Class(
{
   Extends : DialogView,
	
	// ************************************************************************
	// ************************************************************************
	//     MEMBERS VARIABLES
	// ************************************************************************
	// ************************************************************************	

	_iFrame : null,
	_args : null,

	// ************************************************************************
	// ************************************************************************
	//     LIST OF PLUGIN ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************
	
	// ------------------------------------------------------------------------
	// This function returns the list of plug-ins to dynamically load for this component
	//
	// @return {String[]} - the array of plug-ins to load.
	// ------------------------------------------------------------------------
	listJavascriptAssets : function()
	{
		return	[
				];
	},
	
	// For custom protocols, we don't load a matching css file by default.
	// We need one here since we may be displaying a dialog
	listCssAssets : function()
	{
		return	[
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'components/custom/GraingerProtocol/GraingerProtocol.css',
				];
	},

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('GraingerProtocol', this);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theWidgetData (Object) - Contains argument data for the dialog
	// ------------------------------------------------------------------------
	init : function(theBasePath, theWidgetData)
    {
		//
		// Sample link = grainger:type=child&pid=W3124
		//
		var theUrl = theWidgetData.link;
		theUrl = theUrl.substr(theUrl.indexOf(':')+1);
		this._args = theUrl.parseQueryString();
		if (this._args.type === undefined)
		{
			// If type arg not provided, then guess based on the pid format
			// (ie. it is 'child' if first character is an alpha
			var theChar = this._args.pid[0].toLowerCase();
			if ((theChar >= 'a') && (theChar <= 'z'))
				this._args.type = 'parent';
			else
				this._args.type = 'child';
		}

		// We are here if the dirxion hosted url was launched directly. I will
		// display the url's in an iframe like the original demo but place a
		// warning on the title to inform that it was not correctly inside of
		// an iframe on the Grainger site
		var theWidgetOptions = new Object(
		{
			basePath :   theBasePath,
			title:       'WARNING: App not running in IFrame: type='+this._args.type+' pid='+this._args.pid,
			width:       996,
			height:      510,
			hasfooter:   true,
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});
		if (theWidgetData.onClose)
			theWidgetOptions.onClose = theWidgetData.onClose;
		this.parent(theWidgetData, theWidgetOptions);
	},
	
	// ------------------------------------------------------------------------
	// Call this function to see if this component can be init'ed.  
	// ------------------------------------------------------------------------
	canInit : function()
	{
		return (window!=window.top) ? true : this.parent();
	},
	
	// ------------------------------------------------------------------------
	// Call this function to post a message to the parent window to launch the 
	// QuickView window from the Grainger iframe
	// ------------------------------------------------------------------------
	_postItemQVCall : function(type, pid)
	{
		// Get the parent url that we can post a message to. This is hashed on the 
		// iframe src when it is built so that within the iframe context, you can 
		// know what the parent_url is if it ever changes
		parent_url = decodeURIComponent(document.location.hash.replace( /^#/, '' ) );
		if (parent_url == '')
		{
			Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:'The document.location.hash argument was NOT present', title:'Warning'});
		}
		else
		{
			// post the message as an object which is converted to a query string to the grainger.com frame
			jQuery.postMessage({action:'quickview', button:'add', type:type, pid:pid}, parent_url, parent );
			var dialogName = this.componentName;
			dialogName = dialogName.replace('DialogView', '');
			Facade.getInstance().sendNotification(ApplicationFacade.LOG_EVENT, {category:dialogName, action:'Dialog', label:pid});
		}
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{		
		if (window != window.top)
		{
			// We are here if we are correctly running inside an iframe (on Grainger's website)
			this._postItemQVCall(this._args.type, this._args.pid);
		}
		else
		{
			this.parent();		

			var theUrl = 'http://www.grainger.com/search?searchQuery=' + this._args.pid;
			this._iFrame = this._widgetRootElement.getElement('.GraingerProtocol_IFrame');
			this._iFrame.addEvent('load', this._onIFrameContentLoaded.bind(this));
			this._iFrame.src = theUrl;
		}
	},
		
	// ------------------------------------------------------------------------
	// The master iframe with it's code is loaded and ready for interaction here
	// so we can now call it's functions to get it to display it's view
	// ------------------------------------------------------------------------
	_onIFrameContentLoaded : function()
	{
		this._show();
	},

	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});

