// ----------------------------------------------------------------------------
// This View handles the Emerson Cart
// ----------------------------------------------------------------------------
RollwayCart = new Class(
{
	Extends : DialogView,

	// ************************************************************************
	// ************************************************************************
	//     LIST OF ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	hasSkinCoreAsset : function(){return false;},
	// If hasSkinLangAsset is true then _onChangeLanguage() is called when user changes languages (after language resources are loaded)
	hasSkinLangAsset : function(){return true;},

	// ************************************************************************
	// ************************************************************************
	//     MEMBERS VARIABLES
	// ************************************************************************
	// ************************************************************************	
	
	_appState : null,
	_items : new Array(),
	_itemAdded : null,
	
	_itemNameArray : null,
	_productIdArray : null,

	// ********** Add variables for each data field here **********
	
	_emailPanel : null,
	_emailPanelFromName : null,
	_emailPanelToName : null,
	_emailPanelToEmail : null,
	_emailPanelNotes : null,

	_sentPanel : null,
	_listPanel : null,
	_addPanel : null,
	_orderPanel : null,
	
	_buttonContainer : null,
	_buttonActionCenter : null,
	
	_emptyMessage: null,
	_emailBtn : null,
	_orderBtn : null,
	_backBtn : null,
	_back_sentBtn : null,
	_back_orderBtn : null,
	_sendBtn : null,
	_send_orderBtn : null,
	_addBtn : null,
	_cancelBtn : null,
	_continueBtn : null,
	_clearallBtn : null,
	_placeBtn : null,
	_cancelSpriteImage : null,

	_cancel_container : null,
	_add_container : null,
	_continue_container : null,
	_emailOrder_container : null,
	_send_container : null,
	_sendorder_container : null,
	_place_container : null,

	_incButton : null,
	_decButton : null,

	_mooTouchScroller : null,

	_applicationViewElement : null,
	_book : null,
	
	_dialogWidth : null,
	_dialogHeight : null,

	_fields : null,


	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('RollwayCart', this);
	},

    init : function(theBasePath, theDialogData)
    {		

		//View Port Globals
		var viewportWidth = jQuery(window).width();
		var viewportHeight = jQuery(window).height();

		this._applicationViewElement = $('ApplicationView');
		var appSize = this._applicationViewElement.measure(function(){return this.getSize();});
		var appWidth = appSize.x;
		var appHeight = appSize.y;
		
		this._fields = 5;

		if (theDialogData)
		{
			_dialogWidth = 420;
			_dialogHeight = 230;
		}
		else
		{
			if (Browser.Platform.tablet) {
				_dialogHeight = viewportHeight - 54;
				_dialogWidth = viewportWidth - 4;
			}
			else if (appWidth < 1025) {
				_dialogWidth = viewportWidth - 4;
				_dialogHeight = viewportHeight - 37;
			}
			else {
				_dialogHeight = appHeight - 37;
				_dialogWidth = 1060;	
			};
		}
		
		this.parent(theDialogData,
		{
			basePath:           theBasePath,
			title:              Skin.getInstance().get('CartDialogTitle', 'Request for Quotation'),
			width:              _dialogWidth,
			height:				_dialogHeight,
			isDraggable:		false,
			hasFooter:          false,
			isModal: 			true,
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});	
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{	
		this.parent();		

		this._emailPanel = this._widgetRootElement.getElement('#RollwayCart_EmailPanel');
		this._sentPanel = this._widgetRootElement.getElement('#RollwayCart_SentPanel');
		this._listPanel = this._widgetRootElement.getElement('#RollwayCart_ListPanel');
		this._orderPanel = this._widgetRootElement.getElement('#RollwayCart_OrderPanel');
		this._addPanel = this._widgetRootElement.getElement('#RollwayCart_AddPanel');
		this._buttonContainer = this._widgetRootElement.getElement('#RollwayCart_button_container');
		this._buttonActionCenter = this._widgetRootElement.getElement('#RollwayCart_button_container .actionCenter');

		this._emptyMessage = this._widgetRootElement.getElement('#RollwayCart_ListPanel_Empty');
		this._emailBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_email'));
		this._orderBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_order'));
		this._backBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_back'));
		this._back_sentBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_back_sent'));
		this._back_orderBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_back_order'));
		this._sendBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_send'));
		this._send_orderBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_sendorder'));
		this._placeBtn = this._widgetRootElement.getElement('#RollwayCart_button_place');
		this._addBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_add'));
		this._cancelBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_cancel'));
		this._continueBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_continue'));
		this._clearallBtn = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_button_clearall'));

		this._cancel_container = this._widgetRootElement.getElement('#RollwayCart_cancel_container');
		this._add_container = this._widgetRootElement.getElement('#RollwayCart_add_container');
		this._continue_container = this._widgetRootElement.getElement('#RollwayCart_continue_container');
		this._emailOrder_container = this._widgetRootElement.getElement('#RollwayCart_emailOrder_container');
		this._send_container = this._widgetRootElement.getElement('#RollwayCart_send_container');
		this._sendorder_container = this._widgetRootElement.getElement('#RollwayCart_sendorder_container');
		this._place_container = this._widgetRootElement.getElement('#RollwayCart_place_container');

		this._incButton = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_increment'));
		this._decButton = new SpriteButton(this._widgetRootElement.getElement('#RollwayCart_decrement'));

		// ********** Add event handlers (don't forget mooTouchAdd) **********
		this._emailBtn.addEvent('click', this._onClickEmail.bind(this));
		this._orderBtn.addEvent('click', this._onClickOrder.bind(this));
		this._backBtn.addEvent('click', this._onClickBack.bind(this));
		this._back_sentBtn.addEvent('click', this._onClickBack.bind(this));
		this._back_orderBtn.addEvent('click', this._onClickBack.bind(this));
		this._sendBtn.addEvent('click', this._onClickSend.bind(this));
		this._send_orderBtn.addEvent('click', this._onClickSendOrder.bind(this));
		this._addBtn.addEvent('click', this._onClickAdd.bind(this));
		this._cancelBtn.addEvent('click', this._onCancel.bind(this));
		this._continueBtn.addEvent('click', this._onContinue.bind(this));
		this._clearallBtn.addEvent('click', this._onClearAll.bind(this));

		this._emailBtn.mooTouchAdd({'click':true});
		this._orderBtn.mooTouchAdd({'click':true});
		this._placeBtn.mooTouchAdd({'click':true});
		this._backBtn.mooTouchAdd({'click':true});
		this._back_sentBtn.mooTouchAdd({'click':true});
		this._back_orderBtn.mooTouchAdd({'click':true});
		this._sendBtn.mooTouchAdd({'click':true});
		this._send_orderBtn.mooTouchAdd({'click':true});
		this._addBtn.mooTouchAdd({'click':true});
		this._cancelBtn.mooTouchAdd({'click':true});
		this._continueBtn.mooTouchAdd({'click':true});
		this._clearallBtn.mooTouchAdd({'click':true});

		this._incButton.mooTouchAdd({'click':true});
		this._decButton.mooTouchAdd({'click':true});
		
		this._mooTouchScroller = this._listPanel.mooTouchAdd({'scroll':true});
/*
		this._setStyleForLangResource(this._emailBtn,   'background-image', 'RollwayCartEmailBtnPath');
		this._setStyleForLangResource(this._orderBtn,   'background-image', 'RollwayCartOrderBtnPath');
		this._setStyleForLangResource(this._placeBtn,   'background-image', 'RollwayCartPlaceBtnPath');
		this._setStyleForLangResource(this._backBtn,    'background-image', 'RollwayCartBackBtnPath');
		this._setStyleForLangResource(this._back_sentBtn,    'background-image', 'RollwayCartBackSentBtnPath');
		this._setStyleForLangResource(this._back_orderBtn,    'background-image', 'RollwayCartBackOrderBtnPath');
		this._setStyleForLangResource(this._sendBtn,    'background-image', 'RollwayCartSendBtnPath');
		this._setStyleForLangResource(this._send_orderBtn,    'background-image', 'RollwayCartSendBtnPath');
		this._setStyleForLangResource(this._addBtn,     'background-image', 'RollwayCartAddBtnPath');
		this._setStyleForLangResource(this._cancelBtn,  'background-image', 'RollwayCartCancelBtnPath');
		this._setStyleForLangResource(this._continueBtn,'background-image', 'RollwayCartContinueBtnPath');
		this._setStyleForLangResource(this._clearallBtn,'background-image', 'RollwayCartClearAllBtnPath');
*/

		this._items = Preferences.getInstance().get('Cart');
		if (this._items === undefined)
			this._items = [];

		if (this._data)
		{
			var sku_label = Skin.getInstance().get('EmersonItemNumberLabel', 'Item Number');
			var sku = this._data.find('sku').text();
			this._widgetRootElement.getElement('#RollwayCart_sku').set('html', '' + sku_label + ': ' + sku + '');
			var desc_label = Skin.getInstance().get('EmersonDescLabel', 'Item Description');
			var itemDesc = this._data.find('itemdesc').text();
			this._widgetRootElement.getElement('#RollwayCart_itemdesc').set('html', '' + desc_label + ': ' + itemDesc + '');
			var unit_label = Skin.getInstance().get('EmersonUnitLabel', 'Unit of Measurement');
			var unit = this._data.find('unit').text();
			this._widgetRootElement.getElement('#RollwayCart_unit').set('html', '' + unit_label + ': ' + unit + '');			
			var lngDesc = this._data.find('longdesc').text();
			this._widgetRootElement.getElement('#RollwayCart_description').set('html', lngDesc);
			this.width = 300;
			this._onAddList();
		}
		else
		{
			this._updateCount();
			this._onClickList();
		}

		this._buttonContainer.show();
		this._onChangeLanguage();
		this._show();
		// Dialog had to be visible before we arrange footer dialog buttons
		this._RollwayCart_Behaviors();
		this._doButtonContainerLayout();
	},

	_onChangeLanguage : function()
    {
		var qty_txt = Skin.getInstance().get('EmersonQty', 'Qty');
		this._widgetRootElement.getElement('.qty_txt').set('html', '' + qty_txt + '');
		this._emailSpriteImage = Skin.getInstance().getPath('RollwayCartEmailBtnPath');
		this._emailBtn.setImage(this._emailSpriteImage);
		this._orderSpriteImage = Skin.getInstance().getPath('RollwayCartOrderBtnPath');
		this._orderBtn.setImage(this._orderSpriteImage);
		this._backSpriteImage = Skin.getInstance().getPath('RollwayCartBackBtnPath');
		this._backBtn.setImage(this._backSpriteImage);
		this._back_sentSpriteImage = Skin.getInstance().getPath('RollwayCartBackBtnPath');
		this._back_sentBtn.setImage(this._back_sentSpriteImage);
		this._back_orderSpriteImage = Skin.getInstance().getPath('RollwayCartBackBtnPath');
		this._back_orderBtn.setImage(this._back_orderSpriteImage);
		this._sendSpriteImage = Skin.getInstance().getPath('RollwayCartSendBtnPath');
		this._sendBtn.setImage(this._sendSpriteImage);
		this._send_orderSpriteImage = Skin.getInstance().getPath('RollwayCartSendBtnPath');
		this._send_orderBtn.setImage(this._send_orderSpriteImage);
		this._cancelSpriteImage = Skin.getInstance().getPath('RollwayCartCancelBtnPath');
		this._cancelBtn.setImage(this._cancelSpriteImage);
		this._addSpriteImage = Skin.getInstance().getPath('RollwayCartAddBtnPath');
		this._addBtn.setImage(this._addSpriteImage);
		this._continueSpriteImage = Skin.getInstance().getPath('RollwayCartContinueBtnPath');
		this._continueBtn.setImage(this._continueSpriteImage);
		this._clearallSpriteImage = Skin.getInstance().getPath('RollwayCartClearAllBtnPath');
		this._clearallBtn.setImage(this._clearallSpriteImage);
		this._incSpriteImage = Skin.getInstance().getPath('RollwayCartIncBtnPath');
		this._incButton.setImage(this._incSpriteImage);
		this._decSpriteImage = Skin.getInstance().getPath('RollwayCartDecBtnPath');
		this._decButton.setImage(this._decSpriteImage);
		
		var ref_label = Skin.getInstance().get('EmersonRefLabel', 'Item #');
		var detail_label = Skin.getInstance().get('EmersonDetailLabel', 'Item Description');
		var longdetail_label = Skin.getInstance().get('EmersonLongDetailLabel', 'Long Description');
		var uom_label = Skin.getInstance().get('EmersonUOMLabel', 'Unit of Measurement');
		var qty_label = Skin.getInstance().get('EmersonQtyLabel', 'Qty');
		
		this._widgetRootElement.getElement('#RollwayCart_ListPanel_refLabel').set('html', '' + ref_label + '');
		this._widgetRootElement.getElement('#RollwayCart_ListPanel_detailLabel').set('html', '' + detail_label + '');
		this._widgetRootElement.getElement('#RollwayCart_ListPanel_detailLabel2').set('html', '' + longdetail_label + '');
		this._widgetRootElement.getElement('#RollwayCart_ListPanel_priceLabel').set('html', '' + uom_label + '');
		this._widgetRootElement.getElement('#RollwayCart_ListPanel_qtyLabel').set('html', '' + qty_label + '');
		
		var emptymsg = Skin.getInstance().get('EmersonEmptyCart', 'Your cart is empty.');
		var emailtxt0_label = Skin.getInstance().get('EmersonEmailLabel0', 'Email Bill of Material');
		var emailtxt1_label = Skin.getInstance().get('EmersonEmailLabel1', 'Your Name:');
		var emailtxt2_label = Skin.getInstance().get('EmersonEmailLabel2', 'Recipients Name:');
		var emailtxt3_label = Skin.getInstance().get('EmersonEmailLabel3', 'Recipients Email:');
		var emailtxt4_label = Skin.getInstance().get('EmersonEmailLabel4', 'Notes:');
		var req_legend = Skin.getInstance().get('EmersonEmailRequired', '** - Indicates required fields');
		var quotetxt0_label = Skin.getInstance().get('EmersonQuoteLabel0', 'Please fill out your information.');
		var quotetxt1_label = Skin.getInstance().get('EmersonQuoteLabel1', 'Customer Information');
		var quotetxt2_label = Skin.getInstance().get('EmersonQuoteLabel2', 'First Name:');
		var quotetxt3_label = Skin.getInstance().get('EmersonQuoteLabel3', 'Last Name:');
		var quotetxt4_label = Skin.getInstance().get('EmersonQuoteLabel4', 'Title:');
		var quotetxt5_label = Skin.getInstance().get('EmersonQuoteLabel5', 'Company Name:');
		var quotetxt6_label = Skin.getInstance().get('EmersonQuoteLabel6', 'Address:');
		var quotetxt7_label = Skin.getInstance().get('EmersonQuoteLabel7', 'City:');
		var quotetxt8_label = Skin.getInstance().get('EmersonQuoteLabel8', 'State:');
		var quotetxt9_label = Skin.getInstance().get('EmersonQuoteLabel9', 'Zip Code:');
		var quotetxt10_label = Skin.getInstance().get('EmersonQuoteLabel10', 'Country:');
		var quotetxt11_label = Skin.getInstance().get('EmersonQuoteLabel11', 'Telephone Number:');
		var quotetxt12_label = Skin.getInstance().get('EmersonQuoteLabel12', 'Other Telephone Number:');
		var quotetxt13_label = Skin.getInstance().get('EmersonQuoteLabel13', 'Email Address:');
		var quotetxt14_label = Skin.getInstance().get('EmersonQuoteLabel14', 'Confirm Email Address:');
		var quotetxt15_label = Skin.getInstance().get('EmersonQuoteLabel15', 'Account Number:');
		var quotetxt16_label = Skin.getInstance().get('EmersonQuoteLabel16', 'Need product by:');
		var quotetxt17_label = Skin.getInstance().get('EmersonQuoteLabel17', 'Note to System Plast:');
		var senttxt1_label = Skin.getInstance().get('EmersonSentLabel1', 'Thank You!');
		var senttxt2_label = Skin.getInstance().get('EmersonSentLabel2', 'Your Bill of Materials has been sent to:');
		
		
		this._widgetRootElement.getElement('#RollwayCart_EmailPanel_txt0').set('html', '' + emailtxt0_label + '');
		this._widgetRootElement.getElement('#RollwayCart_EmailPanel_txt1').set('html', '' + emailtxt1_label + '');
		this._widgetRootElement.getElement('#RollwayCart_EmailPanel_txt2').set('html', '' + emailtxt2_label + '');
		this._widgetRootElement.getElement('#RollwayCart_EmailPanel_txt3').set('html', '' + emailtxt3_label + '');
		this._widgetRootElement.getElement('#RollwayCart_EmailPanel_txt4').set('html', '' + emailtxt4_label + '');
		this._widgetRootElement.getElement('.required_legend').set('html', '' + req_legend + '');
		this._widgetRootElement.getElement('.required_legend2').set('html', '' + req_legend + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt0').set('html', '' + quotetxt0_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt1').set('html', '' + quotetxt1_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt2').set('html', '' + quotetxt2_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt3').set('html', '' + quotetxt3_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt4').set('html', '' + quotetxt4_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt5').set('html', '' + quotetxt5_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt6').set('html', '' + quotetxt6_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt7').set('html', '' + quotetxt7_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt8').set('html', '' + quotetxt8_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt9').set('html', '' + quotetxt9_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt10').set('html', '' + quotetxt10_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt11').set('html', '' + quotetxt11_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt12').set('html', '' + quotetxt12_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt13').set('html', '' + quotetxt13_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt14').set('html', '' + quotetxt14_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt15').set('html', '' + quotetxt15_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt16').set('html', '' + quotetxt16_label + '');
		this._widgetRootElement.getElement('#RollwayCart_QuotePanel_txt17').set('html', '' + quotetxt17_label + '');
		this._widgetRootElement.getElement('#RollwayCart_SentPanel_txt1').set('html', '' + senttxt1_label + '');
		this._widgetRootElement.getElement('#RollwayCart_SentPanel_txt2').set('html', '' + senttxt2_label + '');
		this._widgetRootElement.getElement('#RollwayCart_ListPanel_EmptyMessage').set('html', '' + emptymsg + '');
		
	},
	
	// ------------------------------------------------------------------------
	// Put any code which needs to be executed when the dialog is closed here
	// ------------------------------------------------------------------------

	
	_onCancel : function()
	{
		this._popUpWindow.close();
	},

	_onContinue : function()
	{
		this._popUpWindow.close();
	},
	
	// ************************************************************************
	// ************************************************************************
	//
	// ************* Add Custom Functions and Event Handlers here *************
	//
	// ************************************************************************
	// ************************************************************************
	_remItem : function(e)
	{
		var theItem = e.target;
		var theButtonId = theItem.get('id');
		var theItemId = theButtonId.substr(theButtonId.lastIndexOf('_')+1);
		var theLineId = 'RollwayCart_ListPanel_itemwrapper_'+theItemId;
		this._listElement = $(theLineId);
		var theItemWrapper = this._listElement.getElementById(theButtonId);
		theItemWrapper.destroy();
		this._items.splice(theItemId, 1);
		this._updateCount();
		this._displayItems();
		if (this._items.length == 0)
		{ 
			this._orderBtn.hide();
		}		
	},
	
	_onPageClick : function(event)
	{
		
		event.preventDefault();
		var theItemLink = event.target.get('href');

		this._popUpWindow.close();

		Facade.getInstance().sendNotification(ApplicationFacade.GOTO_URL, {link:theItemLink});
	},

	_onClickAdd : function(e)
	{
		if (!this._data)
			return;
			
		this._emailElement = this._widgetRootElement.getElement('#RollwayCart_fields');
		var element = this._emailElement.getElementById('RollwayCart_quantity');
		var qty = element.value;



		var theBook = this._appState.get(currentBook);
		var theBookList = this._appState.get(currentBookList);
		var theBookIndex = theBookList.getBookListIndex(theBook.bookCode);
		var theBookListEntry = theBookList.getBookListEntry(theBookIndex);
		var theBookPageIndex = this._appState.get(currentBookPageDest).BookPageIndex;
		var theBookTitle =  theBookListEntry.title;
		var theBookCover = theBookListEntry.thumbnailBig;
		var theBookCoverUrl = theBookListEntry.getBookFolder(false) + theBookListEntry.thumbnailBig;
		//alert(theBookCoverUrl);
		var sku, itemdesc, longdesc, unit, bookcode, pagelabel, booktitle;


		this._itemAdded = sku = this._data.find('sku').text();
		itemdesc = this._data.find('itemdesc').text();
		longdesc = this._data.find('longdesc').text();
		unit = this._data.find('unit').text();
		bookcode = theBook.bookCode;
		booktitle = theBookTitle;
		bookcover = theBookCoverUrl;
		pagelabel = theBook.getPageLabel(theBookPageIndex);

		var notInList = true;
		for (var i = 0; i < this._items.length; i++)
		{
				if ( (this._items[i].itemdesc == itemdesc) && (this._items[i].longdesc == longdesc) && (this._items[i].sku == sku) )
				{
					notInList = false;
					oqty = this._items[i].qty;
					oqty = parseInt(oqty) + parseInt(qty);
					this._items[i].qty = oqty;
				}
		}
		if (notInList)
		{
			this._items.push({itemdesc:itemdesc, longdesc:longdesc, unit:unit, sku:sku, qty:qty, bookcode:bookcode, booktitle:booktitle, bookcover:bookcover, pagelabel:pagelabel});
			Preferences.getInstance().set('Cart', this._items);
			this._updateCount();
		}

		this._cancel_container.show();
		this._add_container.show();

		this._continue_container.hide();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.hide();
		this._place_container.hide();

		this._emailBtn.hide();
		this._orderBtn.hide();
		this._placeBtn.hide();

		this._popUpWindow.close();
	},
	
	_changeQty : function(e)
	{
		var theItem = e.target;
		var theButtonId = theItem.get('id');
		var theItemId = theButtonId.substr(theButtonId.lastIndexOf('_')+1);
		var theLineId = 'RollwayCart_ListPanel_itemwrapper_'+theItemId;
		this._listElement = $(theLineId);
		//RollwayCart_ListPanel_qty_1
		var theItemWrapper = this._listElement.getElementById(theButtonId);
		var newQty = theItemWrapper.value;
		//theItemWrapper.destroy();
		this._items[theItemId].qty = newQty;
	},
	
	_updateCount : function()
	{
		var cnt = 0;
		this._items.each(function(item, index)
		{
			cnt += Number(item.qty);
		});
		this._appState.set(cartListCnt, cnt);
		
		this._items.sort(this._sortByDescription);
		
		Preferences.getInstance().flush(); // rems and adds weren't getting updated if user left dialog without closing it
		
		this._placeBtn.hide();
		
		// Hide/show/the empty cart image
		if (this._items.length == 0)
		{
			this._listPanel.addClass('RollwayCart_EmptyCart');
			this._emailBtn.hide();
			this._orderBtn.hide();
			this._clearallBtn.hide();
			this._emptyMessage.show();

		}
		else
		{
			this._listPanel.removeClass('RollwayCart_EmptyCart');
			this._emailBtn.show();
			this._clearallBtn.show();
			this._emptyMessage.hide();

			if ((Browser.Platform.tablet) || (Browser.Platform.mobile) || (this._items.length == 0)) 
			{ 
				this._orderBtn.hide();
			}
		}
		this._doButtonContainerLayout();
	},
	
	// ------------------------------------------------------------------------
	// This is an array sort helper function which will sort an array of records
	// in ascending order by description name
	// ------------------------------------------------------------------------
	_sortByDescription : function(a, b)
	{
		if (a.longdesc == b.longdesc) return 0;
		if (a.longdesc > b.longdesc) return 1;
		return -1;
	},
	
	_displayItems : function()
	{
		var itemsText = '';
		
		this._items.sort(this._sortByDescription);
		
		var RollwayCart_ListPanel_item = 'RollwayCart_ListPanel_item_even';
		for (var i = 0; i < this._items.length; i++)
		{
			if (RollwayCart_ListPanel_item == 'RollwayCart_ListPanel_item_odd')
				RollwayCart_ListPanel_item = 'RollwayCart_ListPanel_item_even';
			else
				RollwayCart_ListPanel_item = 'RollwayCart_ListPanel_item_odd';
			itemsText += '<div id=\"RollwayCart_ListPanel_itemwrapper_'+i+'\" class=\"'+RollwayCart_ListPanel_item+' row\">';
			
			itemsText += '	<div class=\"RollwayCart_ListPanel_crosslinkcolumn one columns\">';
//			itemsText += '		<div id=\"RollwayCart_ListPanel_'+i+'_wrapper\" class=\"RollwayCart_ListPanel_cover_wrapper four columns\">'
//			itemsText += '		<img class=\"RollwayCart_ListPanel_cover\" src=\"'+this._items[i].bookcover+'\" />';
//			itemsText += '		<a id=\"RollwayCart_ListPanel_coverLink_'+i+'\" class="RollwayCart_ListPanel_coverLink" href=\"app:BookCode='+this._items[i].bookcode+'&PageLabel='+this._items[i].pagelabel+'\"></a>';
//			itemsText += '		</div>'
//			itemsText += '		<a id=\"RollwayCart_ListPanel_booktitle_'+i+'\" class=\"RollwayCart_ListPanel_booktitle eight columns\" href=\"app:BookCode='+this._items[i].bookcode+'&PageLabel='+this._items[i].pagelabel+'\"">'+this._items[i].booktitle+'</a>';
//			itemsText += '		<div id=\"RollwayCart_ListPanel_page_'+i+'_wrapper\" class=\"RollwayCart_ListPanel_page_wrapper eight columns\">';
//			itemsText += '			<a id=\"RollwayCart_ListPanel_page_'+i+'\" class=\"RollwayCart_ListPanel_page\" href=\"app:BookCode='+this._items[i].bookcode+'&PageLabel='+this._items[i].pagelabel+'\">Page: '+this._items[i].pagelabel+'</a>';
//			itemsText += '		</div>';
			itemsText += '		<div class=\"RollwayCart_ListPanel_description twelve columns\">'+this._items[i].sku+'</div>';
			itemsText += '	</div>'

			itemsText += '	<div class=\"RollwayCart_ListPanel_itemdesc three columns\">';
			itemsText += '		<div class=\"RollwayCart_ListPanel_description twelve columns\">'+this._items[i].itemdesc+'</div>';			
			itemsText += '	</div>'
			
			itemsText += '	<div class=\"RollwayCart_ListPanel_detailscolumn three columns\">';
			itemsText += '		<div class=\"RollwayCart_ListPanel_description twelve columns\">'+this._items[i].longdesc+'</div>';


			itemsText += '	</div>';
			
			itemsText += '	<div class=\"three columns\">';
			itemsText += '		<div class=\"RollwayCart_ListPanel_qty eight columns\">'+this._items[i].unit+'</div>';
			itemsText += '		<input type=\"text\" value=\"'+this._items[i].qty+'\" id=\"RollwayCart_ListPanel_qty_'+i+'\" name=\"qty\" class=\"RollwayCart_ListPanel_qty four columns\"/>';
//			itemsText += '		<div class=\"mobilenumbers eight columns\">';
//			itemsText += '			<div class=\"RollwayCart_ListPanel_price twelve columns\"></div>';
//			itemsText += '			<div class=\"RollwayCart_ListPanel_unit twelve columns\">/'+this._items[i].unit+'</div>';
//			itemsText += '		</div>';
			itemsText += '	</div>';

			itemsText += '	<div class=\"RollwayCart_ListPanel_delete two columns\">';
			itemsText += '		<div id="cart_item_'+i+'" class=\"RollwayCart_ListPanel_remove\"></div>';
			itemsText += '	</div>';
			itemsText += '</div>';
		}
		this._listElement = this._widgetRootElement.getElement('#RollwayCart_ListPanel_theList');
	    this._listElement.set('html', itemsText);
		var theElementList;

		//Loop through remove events
		theElementList = this._listElement.getElements('.RollwayCart_ListPanel_remove');
		theElementList.each(function(item, index)
		{
			item.addEvent('click', this._remItem.bind(this));
			item.mooTouchAdd({'click':true});
		}.bind(this));

		//Loop through page link events
		theElementList = this._listElement.getElements('.RollwayCart_ListPanel_coverLink, .RollwayCart_ListPanel_page, .RollwayCart_ListPanel_booktitle');
		theElementList.each(function(item, index)
		{
			item.addEvent('click', this._onPageClick.bind(this));
			item.mooTouchAdd({'click':true});
		}.bind(this));

		//Loop through quantity events
		theElementList = this._listElement.getElements('.RollwayCart_ListPanel_qty');
		theElementList.each(function(item, index)
		{
			item.addEvent('change', this._changeQty.bind(this));
			item.mooTouchAdd({'click':true});
		}.bind(this));

		this._listPanel.show();
		var scrollHeight = 0;
		if ((this._itemAdded != "") && (this._itemAdded != null))
		{
			for (var i = 0; i < this._items.length; i++)
			{
				if (this._itemAdded == this._items[i].recipe)
				{
					//this._mooTouchScroller.scrollTo(0,scrollHeight);
					this._itemAdded = "";
				}
				scrollHeight += this._listElement.getElementById('RollwayCart_ListPanel_itemwrapper_'+i).offsetHeight;
			}
		}
		//this._listPanelWrapper.setStyle('height',scrollHeight);

	},
	
	// ------------------------------------------------------------------------
	// Button click event handlers
	// ------------------------------------------------------------------------
	
	_onClickList : function(e)
	{
		this._cancel_container.hide();
		this._add_container.hide();
		this._continue_container.show();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.hide();
		this._place_container.hide();

		this._addBtn.hide();
		this._placeBtn.hide();
		this._cancelBtn.hide();
		this._backBtn.hide();
		this._back_sentBtn.hide();
		this._back_orderBtn.hide();
		this._sendBtn.hide();
		this._send_orderBtn.hide();
		this._buttonContainer.removeClass('RollwayCart_AddDialog');
		if (this._items.length == 0)
		{

			this._cancel_container.hide();
			this._add_container.hide();
			this._continue_container.show();
			this._emailOrder_container.hide();
			this._send_container.hide();
			this._sendorder_container.hide();

			this._emailBtn.hide();
			this._orderBtn.hide();
			this._clearallBtn.hide();
			this._continueBtn.show();
			this._emptyMessage.show();	
		}	
		else
		{
			this._cancel_container.hide();
			this._add_container.hide();
			this._continue_container.show();
			this._emailOrder_container.show();
			this._send_container.hide();
			this._sendorder_container.hide();

			this._emailBtn.show();
			this._orderBtn.show();
			this._clearallBtn.show();
			this._emptyMessage.hide();			
		}	
		if (this._items.length == 0)
		{
			this._emailOrder_container.show();
			this._orderBtn.hide();
		}
		else
		{
			this._emailOrder_container.show();
			this._orderBtn.show();
		}
		this._doButtonContainerLayout();
		this._displayItems();
		this._sentPanel.hide();
		this._emailPanel.hide();
		this._addPanel.hide();
		this._orderPanel.hide();
		this._listPanel.show();
	},

	_onAddList : function(e)
	{
		
		this._cancel_container.show();
		this._add_container.show();
		this._continue_container.hide();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.hide();

		this._backBtn.hide();
		this._back_sentBtn.hide();
		this._back_orderBtn.hide();
		this._sendBtn.hide();
		this._send_orderBtn.hide();
		this._emailBtn.hide();
		this._orderBtn.hide();
		this._continueBtn.hide();
		
		this._addBtn.show();
		this._cancelBtn.show();
		this._buttonContainer.addClass('RollwayCart_AddDialog');
	
		this._sentPanel.hide();
		this._emailPanel.hide();
		this._orderPanel.hide();
		this._listPanel.hide();
		this._addPanel.show();

	},

	_onClickEmail : function(e)
	{
		this._cancel_container.hide();
		this._add_container.hide();
		this._continue_container.show();
		this._emailOrder_container.hide();
		this._sendorder_container.hide();
		this._send_container.show();

		this._addBtn.hide();
		this._cancelBtn.hide();
		this._continueBtn.hide();
	
		this._emailBtn.hide();
		this._orderBtn.hide();
		this._continueBtn.show();
		this._backBtn.show();
		this._back_sentBtn.hide();
		this._back_orderBtn.hide();
		this._send_orderBtn.hide();
		this._sendBtn.show();
		this._doButtonContainerLayout();

		this._sentPanel.hide();
		this._orderPanel.hide();
		this._listPanel.hide();
		this._addPanel.hide();
		this._emailPanel.show();
	},
	
	_onClickSend : function(e)
	{
		this._emailElement = this._widgetRootElement.getElement('#RollwayCart_EmailPanel');
		var theLanguageList, theLanguageIndex, theLanguageCode;
		theLanguageList = this._appState.get(currentLanguageList);
		theLanguageIndex = this._appState.get(currentLanguageIndex);
		theLanguageCode = theLanguageList.getLanguageCode(theLanguageIndex);
		/*var fields = 0;
		for (var key in this._items[0])
		{
			if (this._items[0].hasOwnProperty(key))
				fields++;
		}
		var length = (this._items.length*fields);*/
		var length = (this._items.length*this._fields);
		var element = this._emailElement.getElementById('RollwayCart_EmailPanel_FromNameField');
		var fromName = element.value;
		var element = this._emailElement.getElementById('RollwayCart_EmailPanel_ToNameField');
		var toName = element.value;
		var element = this._emailElement.getElementById('RollwayCart_EmailPanel_ToEmailField');
		var toEmail = element.value;
		var element = this._emailElement.getElementById('RollwayCart_EmailPanel_NotesField');
		var notes = escape(element.value);

		//validate form input
		toEmail = toEmail.trim();
		if (!FieldValidation.getInstance().isEmailValid(toEmail, 'Recipients Email'))
			return;
		if (!FieldValidation.getInstance().isNameValid(toName, 'Recipients Name'))
			return;		
		if (!FieldValidation.getInstance().isNameValid(fromName, 'Your Name'))
			return;		
		fromEmail = 'noreply@dirxionmail.com';
		this._cancel_container.hide();
		this._add_container.hide();
		this._continue_container.show();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.hide();

		this._addBtn.hide();
		this._cancelBtn.hide();
		this._emailBtn.hide();
		this._orderBtn.hide();
		this._backBtn.hide();
		this._back_sentBtn.show();
		this._back_orderBtn.hide();
		this._sendBtn.hide();
		this._send_orderBtn.hide();
		this._doButtonContainerLayout();
		
		var data1 = '';
		for (var i = 0; i < this._items.length; i++)
		{
			data1 += escape(this._items[i].sku)+'**'+escape(this._items[i].itemdesc)+'**'+escape(this._items[i].longdesc)+'**'+escape(this._items[i].unit)+'**'+escape(this._items[i].qty)+'**';
		}

		var postBody = 'lang='+theLanguageCode+'&length='+length+'&fromEmail='+fromEmail+'&fromName='+escape(fromName)+'&toName='+escape(toName)+'&toEmail='+toEmail+'&notes='+notes+'&data1='+escape(data1);
		var pathToCode = this._getBasePath();
		var isPhoneGap = (window.cordova) ? true : false;
		var theServicePath = REMOTE_PATH_TO_SERVICES;
		if (isPhoneGap)
			pathToCode = theServicePath + pathToCode;
		var myHTMLRequest = new Request.HTML({url: pathToCode + 'ServiceEmailList.php'+CacheMgr.getInstance().getResourceCacheArg('RelId','?')}).post(postBody);

		this._widgetRootElement.getElement('#RollwayCart_SentPanel_ToName').set('html', toName);
		this._widgetRootElement.getElement('#RollwayCart_SentPanel_ToEmail').set('html', toEmail);
		
		var dialogName = this.componentName;
		dialogName = dialogName.replace('DialogView', '');
		Facade.getInstance().sendNotification(ApplicationFacade.LOG_EVENT, {category:dialogName, action:'Emailed'});

		this._orderPanel.hide();
		this._listPanel.hide();
		this._emailPanel.hide();
		this._addPanel.hide();
		this._sentPanel.show();
		this._backBtn.show();
	},

	_onClickOrder : function(e)
	{
		this._cancel_container.hide();
		this._add_container.hide();
		this._continue_container.show();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.show();

		this._addBtn.hide();
		this._cancelBtn.hide();
		this._continueBtn.hide();
	
		this._emailBtn.hide();
		this._orderBtn.hide();
		this._continueBtn.show();
		this._backBtn.hide();
		this._back_sentBtn.hide();
		this._back_orderBtn.show();
		this._sendBtn.hide();
		this._send_orderBtn.show();
		this._doButtonContainerLayout();

		this._sentPanel.hide();
		this._listPanel.hide();
		this._addPanel.hide();
		this._emailPanel.hide();
		this._orderPanel.show();
	},
	
	_onClickSendOrder : function(e)
	{
		var params = {};
		
		var data1 = '';
		for (var i = 0; i < this._items.length; i++)
		{
			data1 += escape(this._items[i].sku)+'**'+escape(this._items[i].itemdesc)+'**'+escape(this._items[i].longdesc)+'**'+escape(this._items[i].unit)+'**'+escape(this._items[i].qty)+'**';
		}

		var theLanguageList, theLanguageIndex, theLanguageCode;
		theLanguageList = this._appState.get(currentLanguageList);
		theLanguageIndex = this._appState.get(currentLanguageIndex);
		theLanguageCode = theLanguageList.getLanguageCode(theLanguageIndex);

		var length = (this._items.length*this._fields);
		var theCompanyCode = Skin.getInstance().get("DefaultCompanyCode");
		var theBook = this._appState.get(currentBook);
		var theBookCode = theBook.bookCode;
		
		params['data1'] = data1;
		params['lang'] = theLanguageCode;
		params['length'] = length;
		params['fields'] = this._fields;
		params['CompanyCode'] = theCompanyCode;
		params['BookCode'] = theBookCode;
	
		this._orderPanelElement = this._widgetRootElement.getElement('#RollwayCart_OrderPanel');
		
		//validate form input
		var element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_FirstNameField');
		var firstName = element.value;
		if (!FieldValidation.getInstance().isNameValid(firstName, 'First Name'))
			return;
		params['firstName'] = firstName;
		
		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_LastNameField');
		var lastName = element.value;
		if (!FieldValidation.getInstance().isNameValid(lastName, 'Last Name'))
			return;
		params['lastName'] = lastName;
		
		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_TitleField');
		params['title'] = element.value;

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_CompanyNameField');
		var companyName = element.value;
		if (!FieldValidation.getInstance().isNameValid(companyName, 'Company Name'))
			return;
		params['companyName'] = companyName;

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_StreetAddressField');
		var streetAddress = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(streetAddress, 'Street Address'))
			return;
		params['streetAddress'] = streetAddress;

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_CityAddressField');
		var cityAddress = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(cityAddress, 'City'))
			return;
		params['cityAddress'] = cityAddress;

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_StateAddressField');
		var stateAddress = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(stateAddress, 'State'))
			return;
		params['stateAddress'] = stateAddress;

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ZipAddressField');
		var zipAddress = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(zipAddress, 'Zip Code'))
			return;
		params['zipAddress'] = zipAddress;
		
		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_CountryAddressField');
		var countryAddress = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(countryAddress, 'Country'))
			return;
		params['countryAddress'] = countryAddress;

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_TelephoneNumberField');
		var telephoneNumber = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(telephoneNumber, 'Telephone'))
			return;
		params['telephoneNumber'] = telephoneNumber;

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_OtherTelephoneNumberField');
		params['otherTelephoneNumber'] = element.value;

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_EmailAddressField');
		var emailAddress = element.value;
		emailAddress = emailAddress.trim();
		if (!FieldValidation.getInstance().isEmailValid(emailAddress, 'Email Address'))
			return;
		params['emailAddress'] = emailAddress;

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ConfirmEmailAddressField');
		var confirmEmailAddress = element.value;
		confirmEmailAddress = confirmEmailAddress.trim();
		if (!FieldValidation.getInstance().isEmailValid(confirmEmailAddress, 'Confirm Email Address'))
			return;
		
		if (emailAddress != confirmEmailAddress)
		{
			Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:"Email address doesn't match confirm email address field.", title:title});
			return;
		}

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_AccountNumberField');
		params['accountNumber'] = element.value;
		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_NeedProductByField');
		params['needProductBy'] = element.value;
		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_NoteToSystemPlastField');
		params['noteToSystemPlast'] = element.value;
		
		var theBookPageIndex = this._appState.get(currentBookPageDest).BookPageIndex;
		var secidx = theBook.getSectionIndex(theBookPageIndex);
		theBookPageIndex = theBookPageIndex.toInt();
		
		// Empty the cart items from the dialog
		this._onClearAll();
		var aspfile = (RELATIVE_PATH_TO_CODE.indexOf('-bin')>-1) ? '' : 'debug.php';
		theUrlStr = REMOTE_PATH_TO_SERVICES + aspfile+'?BookCode='+theBookCode+'&Sgt='+secidx+'&PageLabel='+theBook.getPageLabel(theBookPageIndex);
		theImageUrlStr = this._getBasePath();
		if (window.cordova)
			theImageUrlStr = REMOTE_PATH_TO_SERVICES + this._getBasePath();
		params['return_url'] = theUrlStr;
		params['image_url'] = theImageUrlStr;
		
		var theSupportInfoMap = Skin.getInstance().getPlatformStyle('SupportInfoMap','');
		var email_to = null;
		var support_no_str = null;
		if (theSupportInfoMap != '')
		{
			for (var i=0; i<theSupportInfoMap.length; i++)
			{
				if (theSupportInfoMap[i].BookCode == theBookCode)
				{
					email_to = theSupportInfoMap[i].EmailTo;
					support_no_str = theSupportInfoMap[i].SupportNo;
					break;
				}
			}
		}

		if ((email_to != null) && (support_no_str != null))
		{
			params['email_to'] = email_to;
			params['support_no_str'] = support_no_str;
		}
		else
		{
			params['missing_support_info'] = 'true';		
		}
		
		var theServicePath = this._getBasePath();
		if (window.cordova)
			theServicePath = REMOTE_PATH_TO_SERVICES + this._getBasePath();
		this._post_to_url(theServicePath + 'ServiceCheckOut.php', params);
		Facade.getInstance().sendNotification(ApplicationFacade.LOG_EVENT, {category:this.componentName.replace('DialogView',''), action:'Checkout'});
	},
	
	_post_to_url : function(path, params, method) 
	{
	    method = method || "post"; // Set method to post by default, if not specified.

	    // The rest of this code assumes you are not using a library.
	    // It can be made less wordy if you use one.
	    var form = document.createElement("form");
	    form.setAttribute("method", method);
	    form.setAttribute("action", path);

	    for(var key in params) {
	        if(params.hasOwnProperty(key)) {
	            var hiddenField = document.createElement("input");
	            hiddenField.setAttribute("type", "hidden");
	            hiddenField.setAttribute("name", key);
	            hiddenField.setAttribute("value", params[key]);

	            form.appendChild(hiddenField);
	         }
	    }

	    document.body.appendChild(form);
	    form.submit();
	},
	
	_onShipMatchesBilling : function(e)
	{
		this._orderPanelElement = this._widgetRootElement.getElement('#RollwayCart_OrderPanel');
		var element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingNameField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingAddressField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingCityField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingStateField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingZipCodeField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingPhoneField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingCountryField');
		element.disabled = true;
		element.value = 'Using Billing Information';
	},
	
	_onShipDoesntMatchBilling : function(e)
	{
		this._orderPanelElement = this._widgetRootElement.getElement('#RollwayCart_OrderPanel');
		var element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingNameField');
		element.disabled = false;
		element.value = '';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingAddressField');
		element.disabled = false;
		element.value = '';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingCityField');
		element.disabled = false;
		element.value = '';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingStateField');
		element.disabled = false;
		element.value = '';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingZipCodeField');
		element.disabled = false;
		element.value = '';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingPhoneField');
		element.disabled = false;
		element.value = '';

		element = this._orderPanelElement.getElementById('RollwayCart_OrderPanel_ShippingCountryField');
		element.disabled = false;
		element.value = '';
	},

	_onClearAll : function(e)
	{
		this._items = [];
		Preferences.getInstance().set('Cart', this._items);
		this._updateCount();
		this._displayItems();
	},
	
	_onClickBack : function(e)
	{
		this._cancel_container.hide();
		this._add_container.hide();
		this._continue_container.show();
		this._emailOrder_container.show();
		this._send_container.hide();
		this._sendorder_container.hide();
		this._place_container.hide();

		this._addBtn.hide();
		this._cancelBtn.hide();

		this._sendBtn.hide();
		this._send_orderBtn.hide();
		this._orderBtn.show();
		this._backBtn.hide();
		this._back_sentBtn.hide();
		this._back_orderBtn.hide();
		this._emailBtn.show();
		this._doButtonContainerLayout();

		this._emailPanel.hide();
		this._sentPanel.hide();
		this._addPanel.hide();
		this._orderPanel.hide();
		this._listPanel.show();		
	},
		
	_doButtonContainerLayout : function()
	{
		// Set the container left to zero before measuring to make sure buttons will all fit side by side without wrapping
		this._buttonActionCenter.setStyle('left',0);
		var theParentSize = this._buttonContainer.measure(function(){return this.getSize();});
		var theSize = this._buttonActionCenter.measure(function(){return this.getSize();});
		this._buttonActionCenter.setStyle('left',(theParentSize.x/2) - (theSize.x/2));
	},

	_RollwayCart_Behaviors : function()
	{	
		jQuery("#RollwayCart_increment").click(function() {
		    var curValue = jQuery('#RollwayCart_quantity').val();
		    var curNumber = parseFloat(curValue);

			jQuery('#RollwayCart_quantity').val(curNumber + 1);
		});


		jQuery("#RollwayCart_decrement").click(function() {
		    var curValue = jQuery('#RollwayCart_quantity').val();
		    var curNumber = parseFloat(curValue);
		    	if ( curNumber >= 2) {
					jQuery('#RollwayCart_quantity').val(curNumber - 1);
				} else {
					//
				}
		});

		jQuery(window).resize(function() {
			//alert('resized!');
			var viewportWidth = jQuery(window).width();
			var viewportHeight = jQuery(window).height();
			
			if (jQuery('#RollwayCart_button_container').hasClass('RollwayCart_AddDialog')) {

			}
			else {

				if (viewportWidth < 1025) {
					jQuery('.popUpWindow.RollwayCart').parent().width(viewportWidth);
					jQuery('.popUpWindow.RollwayCart').parent().css({"left":"0px","top":"0px"});
					jQuery('.popUpWindow.RollwayCart').width(viewportWidth);					
				}
				jQuery('.popUpWindow.RollwayCart').parent().height(viewportHeight);
				jQuery('.popUpWindow.RollwayCart').parent().css({"top":"0px"});
				jQuery('.popUpWindow.RollwayCart').height(viewportHeight);
			}
		});

		window.onorientationchange = function(){
		    var orientation = window.orientation;
		    // Look at the value of window.orientation:
		    if (orientation === 0){
		        // iPad is in Portrait mode.
		        jQuery('.popUpWindow.RollwayCart').parent().width(viewportWidth);
				jQuery('.popUpWindow.RollwayCart').parent().css({"left":"0px","top":"0px"});
				jQuery('.popUpWindow.RollwayCart').width(viewportWidth);
		    }
		    else if (orientation === 90){
		        // iPad is in Landscape mode. The screen is turned to the left.
		        jQuery('.popUpWindow.RollwayCart').parent().width(viewportWidth);
				jQuery('.popUpWindow.RollwayCart').parent().css({"left":"0px","top":"0px"});
				jQuery('.popUpWindow.RollwayCart').width(viewportWidth);
		    }
		    else if (orientation === -90){
		        // iPad is in Landscape mode. The screen is turned to the right.
		        jQuery('.popUpWindow.RollwayCart').parent().width(viewportWidth);
				jQuery('.popUpWindow.RollwayCart').parent().css({"left":"0px","top":"0px"});
				jQuery('.popUpWindow.RollwayCart').width(viewportWidth);
		    }
		}
	},
	
	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});
