// ----------------------------------------------------------------------------
// This View handles the QuickviewProtocol links
// ----------------------------------------------------------------------------
SomaProtocol = new Class(
{
   Extends : DynamicComponent,
	
	// ************************************************************************
	// ************************************************************************
	//     MEMBERS VARIABLES
	// ************************************************************************
	// ************************************************************************	

	_appState : null,
	_args : null,

	// ************************************************************************
	// ************************************************************************
	//     LIST OF PLUGIN ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************
	
	// ------------------------------------------------------------------------
	// The QuickviewProtocol-core.txt skin file is being loaded because we will 
	// probably want to add skin options for slight differences in functionality 
	// for different customers.
	// ------------------------------------------------------------------------
	hasSkinCoreAsset : function(){return false;},
	
	// ------------------------------------------------------------------------
	// Currently don't need language resource files because the only displayed 
	// message is a warning just for us
	// ------------------------------------------------------------------------
	hasSkinLangAsset : function(){return false;},

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('SomaProtocol', this);
		this._appState = Facade.getInstance().retrieveProxy(AppState.NAME);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theWidgetData (Object) - Contains argument data for the dialog
	// ------------------------------------------------------------------------
	init : function(theBasePath, theWidgetData)
	{
		this.parent(theWidgetData,
		{
			basePath : theBasePath,
		});
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{	
		//
		// Sample link = soma:action=quickview&type=child&pid=W3124
		//
		var theUrl = this._data.link;
		theUrl = theUrl.substr(theUrl.indexOf(':')+1);
		var theArgs = theUrl.parseQueryString();
		if (theArgs.action === undefined)
			theArgs.action = 'quickview';

		// Check to see if we are correctly running inside an iframe on the customer website
		if (window != window.top)
		{
			// We are here if we are correctly running inside an iframe (on Soma's website)
			if (theArgs.action == 'quickview')
			{
				this._postItemQVCall(theArgs.pid);
			}
			else if (theArgs.action == 'bagcount')
			{
				// Sample: soma:action=bagcount&count=22
				this._appState.set(cartListCnt, theArgs.count);
			}
		}
		else
		{
			// If the dirxion hosted url was launched directly (rather than displayed
			// in an iframe on the customers site), display the link in a dialog box 
			// with a warning that we were not properly launched within an iframe.
			// NOTE: Shouldn't need language resource for this string because this
			//       warning message is really for us.
			var theTitle = 'WARNING: Not running in Iframe';
			var theMessage = theUrl;
			Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:theMessage, title:theTitle});
		}
	},
	
	_postItemQVCall : function(pid)
	{
		// Get the parent url that we can post a message to. This is hashed on the 
		// iframe src when it is built so that within the iframe context, you can 
		// know what the parent_url is if it ever changes
		var parent_url = decodeURIComponent(document.location.hash.replace( /^#/, '' ) );
		if (parent_url == '')
		{
			//Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:'The document.location.hash argument was NOT present', title:'Warning'});
			parent_url = '*';
		}
		// post the message as an object which is converted to a query string to the soma.com frame
		jQuery.postMessage(pid, parent_url, parent );
	},


	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});

