// ----------------------------------------------------------------------------
// This View handles the Template Component
// ----------------------------------------------------------------------------
AppWidget = new Class(
{
   Extends : WidgetView,
	
	// ************************************************************************
	// ************************************************************************
	//     MEMBERS VARIABLES
	// ************************************************************************
	// ************************************************************************	

	_imageElement : null,
	_timerId : null,

	// ************************************************************************
	// ************************************************************************
	//     LIST OF ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	// If hasSkinLangAsset is true then _onChangeLanguage() is called when user changes languages (after language resources are loaded)
	hasSkinLangAsset : function(){return true;},

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('AppWidget', this);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theWidgetData (Object) - Contains argument data for the dialog
	// ------------------------------------------------------------------------
	init : function(theBasePath, theWidgetData)
    {
    	if (window.cordova)
    		return;

		if (Browser.Platform.ios)
		{
			var theWidth = '300';
			var theHeight = '89';
		}
		else if (Browser.Platform.android)
		{
			var theWidth = '257';
			var theHeight = '89';
		}

		// Make sure the image widget will fit on the device...if not then scale proportionally until it will
		var theDeviceWidth = DeviceMgr.getInstance().getOrientationScreenWidth()*window.devicePixelRatio*0.95;
		var theDeviceHeight = DeviceMgr.getInstance().getOrientationScreenHeight()*window.devicePixelRatio*0.95;
		
		var theScaleTemp, theScale;
		theScale = theScaleTemp = 1.0;
		if (theDeviceWidth < theWidth)
		{
			theScaleTemp = theDeviceWidth/theWidth;
			theScale = (theScaleTemp < theScale) ? theScaleTemp : theScale;
		}
		if (theDeviceHeight < theHeight)
		{
			theScaleTemp = theDeviceHeight/theHeight;
			theScale = (theScaleTemp < theScale) ? theScaleTemp : theScale;
		}
		if (!Browser.Platform.desktop)
		{
			if (theDeviceHeight < theWidth)
			{
				theScaleTemp = theDeviceHeight/theWidth;
				theScale = (theScaleTemp < theScale) ? theScaleTemp : theScale;
			}
			if (theDeviceWidth < theHeight)
			{
				theScaleTemp = theDeviceWidth/theHeight;
				theScale = (theScaleTemp < theScale) ? theScaleTemp : theScale;
			}
		}
		theWidth *= theScale;
		theHeight *= theScale;
		
		var theWidgetOptions = new Object(
		{
			basePath : theBasePath,
			title:  '',				// Need to set this in onContentLoaded so it will pick up translated title from the component skin
			anchor: theWidgetData.Anchor,
			isClosable: !theWidgetData.Anchor.test(/.*\-banner/),
			isModal: true,
			width:  theWidth,
			height: theHeight,
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});
		if (theWidgetData.onClose)
			theWidgetOptions.onClose = theWidgetData.onClose;
		this.parent(theWidgetData, theWidgetOptions);
	},

	//----------------------------------------------------------------------
	// Used to change cursor prop if link does not exist
	// accepts - link to image
	//----------------------------------------------------------------------
	
	_linkCursorProp : function(theLink)
	{
		var pointerStyle = this._imageElement.getStyle('cursor');
		if(theLink != undefined && theLink != '') // has link
		{
			if(pointerStyle === 'default')
				this._imageElement.setStyle('cursor', 'pointer');
		}
		else if (pointerStyle === 'pointer')
			this._imageElement.setStyle('cursor', 'default');
	},
	
	//----------------------------------------------------------------------
	// Used to control whether the image appears clickable.
	// accepts - link to image
	//----------------------------------------------------------------------
	_linkProp : function()
	{
		var theLink = this._data.Link;
		if (!theLink)
			theLink = this._data.link;
		this._linkCursorProp(theLink);
	},
	
	//----------------------------------------------------------------------
	// Used to control whether the rotating image appears clickable.
	// accepts - index to image link array
	//----------------------------------------------------------------------
	_rotateBannerLinkProp : function(index)
	{
		var theLink = this._imagesArray[index].Link;
		if (!theLink)
			theLink = this._imagesArray[index].link;
		this._linkCursorProp(theLink);
	},

	// ------------------------------------------------------------------------
	// Put any code which needs to be executed when the widget is closed here
	// ------------------------------------------------------------------------
	onClose : function() 
	{
		if (this._timerId)
			clearInterval(this._timerId);
		this.parent();
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{		
		this.parent();

		if (this._data.Time == undefined)
		{
			this._imageElement = this._widgetRootElement.getElement('.AppWidget_Image');
			this._imageElement.addEvent('click', this._onClick.bind(this));
			this._imageElement.mooTouchAdd({'click':true});
			this._imageElement.addEvent('load', this._onImageContentLoaded.bind(this));
			
			this._iosLink = ('html', this._getBasePath()+'images/'+Skin.getInstance().get('App_Ios_Link', ''));
			this._androidLink = ('html', this._getBasePath()+'images/'+Skin.getInstance().get('App_Android_Link', ''));

			if ((Browser.Platform.ios) && (this._iosLink))
				var theUrl = this._iosLink
			else if ((Browser.Platform.android) && (this._androidLink))
				var theUrl = this._androidLink

			this._setImage(this._imageElement, theUrl);
			this._linkProp();
		}
		else
		{		
			this._imageElement = this._widgetRootElement.getElement('.AppWidget_Image');
			this._imageElement.setStyle('cursor', 'default');
			this._imageElement.addEvent('click', this._onClickRotate.bind(this));
			this._imageElement.mooTouchAdd({'click':true});
			this._baseImagePath = this._data.BasePath;
			this._imagesArray = this._data.Images;
			this._imagesArrayIndex = 0;
			this._setImage(this._imageElement, this._imagesArray[this._imagesArrayIndex].Url);
			this._imageElement.addEvent('load', this._onImageContentLoaded.bind(this));
			this._rotateBannerLinkProp(this._imagesArrayIndex);
			this._timerId = this._onRotate.periodical(this._data.Time, this);
		}
	},

	_onImageContentLoaded : function()
	{
		this._show();
	},
	
	// ------------------------------------------------------------------------
	// Timer event handler for the rotating the image 
	// ------------------------------------------------------------------------
	_onRotate : function ()
	{
		this._imagesArrayIndex++;
		if (this._imagesArrayIndex >= this._imagesArray.length)
			this._imagesArrayIndex = 0;
		this._setImage(this._imageElement, this._imagesArray[this._imagesArrayIndex].Url);
		this._rotateBannerLinkProp(this._imagesArrayIndex);
	},

	// ------------------------------------------------------------------------
	// Event handler for the click event on the image link.  Should honor current
	// data object.
	// ------------------------------------------------------------------------
    _onClickRotate : function()
    {
		var theLink = this._imagesArray[this._imagesArrayIndex].Link;
		if (!theLink)
			theLink = this._imagesArray[this._imagesArrayIndex].link;
		// Do not call GOTO URL if link is not present
		if(theLink != undefined && theLink != '')
			Facade.getInstance().sendNotification(ApplicationFacade.GOTO_URL, {link:theLink, source:'Link'})
    },
    _onClick : function()
    {
		var theLink = this._data.Link;
		if (!theLink)
			theLink = this._data.link;
		// Do not call GOTO URL if link is not present
		if(theLink != undefined && theLink != '')
			Facade.getInstance().sendNotification(ApplicationFacade.GOTO_URL, {link:theLink, source:'Link'})
    },	


	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});