// ----------------------------------------------------------------------------
// This View handles the FatalError Component.  This is used when an error
// occurs which is severe enough that the user can't continue using the product.
// In this case, the BookshelfView and ApplicationView components are hidden
// and a non-closeable error message is displayed using the full screen area.
// ----------------------------------------------------------------------------
FatalError = new Class(
{
   Extends : DynamicComponent,
	
	// ************************************************************************
	// ************************************************************************
	//     MEMBER VARIABLES
	// ************************************************************************
	// ************************************************************************	
	
	_toolbarView : null,
	_bookshelfGridBody : null,
	_bookshelfGridWrapper : null,
	_fatalErrorTitleWrapper : null,
	
	_fatalErrorWrapper : null,
	_fatalErrorTitleWrapper : null,
	_fatalErrorIcon : null,
	_fatalErrorTitleContainer : null,
	_fatalErrorTitle : null,
	_fatalErrorDescription : null,
	_fatalErrorView : null,

	// ************************************************************************
	// ************************************************************************
	//     LIST OF PLUGIN ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	hasSkinCoreAsset : function(){return true;},
	// If hasSkinLangAsset is true then _onChangeLanguage() is called when user changes languages (after language resources are loaded)
	hasSkinLangAsset : function(){return true;},

	// ------------------------------------------------------------------------
	// These functions return the list of plug-in assets to dynamically load for 
	// this component
	// ------------------------------------------------------------------------
	listJavascriptAssets : function(){return [];},
	listCssAssets : function(){return [];},
	
	// ------------------------------------------------------------------------
	// This function returns a path to an optional html asset to load for this 
	// component
	// ------------------------------------------------------------------------
	listHtmlAsset : function(){return 'FatalError.html';},

	// ************************************************************************
	// ************************************************************************
	//     MEDIATOR FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// This function returns the list of notifications to register this view for.
	//
	// @return {String[]} - the array of notification names to act upon.
	// ------------------------------------------------------------------------
	listNotificationInterests : function()
	{
		var theArray = this.parent().append
		(
			[
				ApplicationFacade.APPLICATION_RESIZED,
				ApplicationFacade.ORIENTATION_CHANGED,
				ChangeLanguageCommand.LANG_LOADED
			]
		);
        return theArray;
	},

	// ------------------------------------------------------------------------
	// This is a proxy for the UIMediator handleNotification function.
	//
	// This function is called to handle all notifications listed in the 
	// listNotificationInterests function
	//
	// Arguments:
	//     notification (Notification) - The notification to act upon
	// ------------------------------------------------------------------------
	handleNotification : function(notification)
	{
		switch(notification.getName())
		{
			case ApplicationFacade.APPLICATION_RESIZED:
			case ApplicationFacade.ORIENTATION_CHANGED:
				this.parent(notification);
				this._onApplicationResized.delay(100,this);
				break;
			case ChangeLanguageCommand.LANG_LOADED:
				this.parent(notification);
				this._onChangeLanguage();
				break;
			default:
				this.parent(notification);
				break;
		}
	},

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('FatalError', this);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theComponentData (Object) - Contains argument data for the component
	// ------------------------------------------------------------------------

	init : function(theBasePath, theComponentData)
    {		
		this._fatalErrorView = new Element('div');
		// Initialize the toolbar before pageCtlView because the toolbar min-width will also control pageCtlView min-width
		this._toolbarView = new ToolbarView('FatalErrorTbLeft', 'FatalErrorTbCenter', 'FatalErrorTbRight');
		// Added pageCtl class so it will inherit pageCtl css styling in main.css
		this._bookshelfGridBody = Elements.from(
		'	<div class="BookshelfView_gridBody pageCtl toolbarOffset"> \
				<div class="BookshelfView_gridWrapper">                \
				</div>                                                 \
			</div>                                                     \
		')[0];
		this._bookshelfGridWrapper = this._bookshelfGridBody.getElement('.BookshelfView_gridWrapper');

		this.parent(theComponentData,
		{
			basePath : theBasePath,
			title:  '',				// Need to set this in onContentLoaded so it will pick up translated title from the component skin
			injectLocation: this._bookshelfGridWrapper,
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Javascript/Html/Css assets (if any) are loaded by the time this
	// function is called so here we create and add any extra UIComponents
	// and attach event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{		
		this.parent();
		this._fatalErrorView.addClass('FatalError');
		
		this._fatalErrorView.grab(this._toolbarView.element);
		this._fatalErrorView.grab(this._bookshelfGridBody);
		
		this._fatalErrorWrapper = this._bookshelfGridWrapper.getElement('#FatalError_Wrapper');
		this._fatalErrorTitleWrapper = this._bookshelfGridWrapper.getElement('#FatalError_TitleWrapper');
		this._fatalErrorIcon    = this._bookshelfGridWrapper.getElement('#FatalError_Icon');
		this._fatalErrorTitleContainer = this._bookshelfGridWrapper.getElement('#FatalError_Title_Container');
		this._fatalErrorTitle = this._bookshelfGridWrapper.getElement('#FatalError_Title');
		this._fatalErrorDescription = this._bookshelfGridWrapper.getElement('#FatalError_Description');

		var theSplashView = $('SplashView');
		var theBookshelfView = $('BookshelfView');
		var theApplicationView = $('BookshelfView');
		if (theBookshelfView)
			theBookshelfView.hide();
		if (theApplicationView)
			theApplicationView.hide();
		if (theSplashView)
			theSplashView.hide();
			
		var theBody = $$('body')[0];
		this._fatalErrorView.inject(theBody);
		
		// Finish loading the toolbar elements (since it is an UIComponent class)
		this._toolbarView.initializeChildren();
		this._toolbarView.childrenInitialized();

		this._onChangeLanguage();
	},

	// ------------------------------------------------------------------------
	// This function handles window resize event.  
	// ------------------------------------------------------------------------
	_onApplicationResized : function()
	{
		this._doLayout();
	},

	// ------------------------------------------------------------------------
	// This function will layout the FatalError component 
	// ------------------------------------------------------------------------
	_doLayout : function()
	{
		var theMaxDisplayWidth = 800;
		var thePadding = Browser.Platform.mobile ? 10:20		
		
		if (Browser.Platform.mobile)
		{
			var theScreenWidth;
			if (Browser.Platform.ios)
				theScreenWidth = DeviceMgr.getInstance().getOrientationScreenWidth();
			else if (Browser.Platform.mobile && (Browser.Platform.android))
				theScreenWidth = DeviceMgr.getInstance().getOrientationScreenWidth()*window.devicePixelRatio;
			this._bookshelfGridBody.setStyle('width',theScreenWidth);
		}
		
		this._fatalErrorWrapper.setStyle('padding', thePadding);
		
		// NOTE: Mootools computeSize has a bug.  For non-IE browsers if computeSize is specified with 'border and 'padding'
		//       attributes, the totalWidth will include them twice.  Therefore totalWidth needs to be corrected for non-IE.
		var theDisplayAreaSize = this._bookshelfGridWrapper.measure(function(){return this.getDimensions({computeSize:true, styles:['margin','padding','border']});}); 
		if (!Browser.ie)
			theDisplayAreaSize.totalWidth -= theDisplayAreaSize['border-left-width'] + theDisplayAreaSize['border-right-width'] + theDisplayAreaSize['padding-left'] + theDisplayAreaSize['padding-right'];
		var theFatalErrorWrapperSize = this._fatalErrorWrapper.measure(function(){return this.getDimensions({computeSize:true, styles:['margin','padding','border']});}); 
		if (!Browser.ie)
			theFatalErrorWrapperSize.totalWidth -= theFatalErrorWrapperSize['border-left-width'] + theFatalErrorWrapperSize['border-right-width'] + theFatalErrorWrapperSize['padding-left'] + theFatalErrorWrapperSize['padding-right'];
		var theTotalAvailableSpace = theFatalErrorWrapperSize.width - theFatalErrorWrapperSize['border-left-width'] - theFatalErrorWrapperSize['border-right-width'] - theFatalErrorWrapperSize['padding-left'] - theFatalErrorWrapperSize['padding-right'];
		var theAvailableSpace = theTotalAvailableSpace;
		if (theAvailableSpace > theMaxDisplayWidth)
			theAvailableSpace = theMaxDisplayWidth;

		var theIconSize = this._fatalErrorIcon.measure(function(){return this.getDimensions();});
		this._titleSize = this._measureTextBlock(this._fatalErrorTitle.get('text'), 'FatalError_Title', theAvailableSpace-thePadding-theIconSize.width-thePadding, 0);
		this._descSize = this._measureTextBlock(this._fatalErrorDescription.get('text'), 'FatalError_Description', theAvailableSpace, 0);
		
		var theBlockWidth = this._titleSize.width + theIconSize.width + thePadding;
		if (this._descSize.width > theBlockWidth)
			theBlockWidth = this._descSize.width;

		var theTop = 0;
		var theLeftOffset = (theTotalAvailableSpace - theBlockWidth)/2;
		var theTotalHeight = theIconSize.height;
		theTotalHeight += this._descSize.height;
		var theTopOffset = (theDisplayAreaSize.height - theTotalHeight)/2;

		this._fatalErrorIcon.setStyles(
		{
			'position':'absolute',
			'top':theTopOffset + theTop,
			'left':theLeftOffset + thePadding		
		});
		theTop = (theIconSize.height-this._titleSize.height)/2;
		this._fatalErrorTitleContainer.setStyles(
		{
			'position':'absolute',
			'text-align':'left',
			'top':theTopOffset + theTop,
			'left':theLeftOffset + thePadding + theIconSize.width + thePadding, 
			'width':theAvailableSpace - thePadding - theIconSize.width - thePadding,
			'height':this._titleSize.height
		});
		theTop += (theIconSize.height > this._titleSize.height) ? theIconSize.height : this._titleSize.height;
		this._fatalErrorDescription.setStyles(
		{
			'position':'absolute',
			'text-align':'left',
			'top':theTopOffset + theTop,
			'left':theLeftOffset + thePadding,
			'width':theAvailableSpace,
			'height':this._descSize.height
		});
	},
	
	// ------------------------------------------------------------------------
	// This function returns the width/height of a block of text.
	// ------------------------------------------------------------------------
	_measureTextBlock : function(theText, theClass, theMaxWidth, theMinWidth)
	{
		var theElements = Elements.from(
		'                                        \
			<div>                                \
				<div class="theMeasureText">     \
			</div>                               \
		');
		var theRootElement = theElements[0];
		theRootElement.setStyles({'position':'absolute', 'display':'inline-block', 'visibility':'hidden'});
		if (theClass != undefined)
			theRootElement.addClass(theClass);
		if (theMinWidth != undefined)
			theRootElement.setStyles({'left':-theMinWidth, 'min-width':theMinWidth});
		if (theMaxWidth != undefined)
			theRootElement.setStyles({'left':-theMaxWidth, 'max-width':theMaxWidth});
		var theTextElement = theRootElement.getElement('.theMeasureText');
		theTextElement.set('text', theText);
		document.body.grab(theRootElement);
		var theElementSize = theRootElement.measure(function(){return this.getDimensions();});
		theRootElement.dispose();
		
		return theElementSize;
	},
	
	// ------------------------------------------------------------------------
	// Event handler for changing strings and other language based resources
	// when the language is changed.
	// ------------------------------------------------------------------------
	_onChangeLanguage : function()
	{
		// Update the browser title bar	
		if (!Browser.ie)
		{
			// I had to use the following convoluted way to get special characters such as tradmark in the title.
			// Normally you would call .set('html', theText) to have the &reg; processed into the correct display
			// but Safari only allows .set('text', theText) on the title element.  So I use another fake element
			// to get the special html characters processed and then insert into the title
			var tmp = new Element('span', {html: Skin.getInstance().get('ProductName','Dirxion Demo')});
			$$('title')[0].set('text',tmp.get('text'));
		}
		else // IE
		{
			var tmp = new Element('span', {html: Skin.getInstance().get('ProductName','Dirxion Demo')});
			//document.title = Skin.getInstance().get('ProductName','Dirxion Demo');
			document.title = tmp.get('text');
		}
		
		var title = '';
		if (this._data.ErrorTitleSkinKey)
			title = Skin.getInstance().getPlatformStyle(this._data.ErrorTitleSkinKey, this._data.ErrorTitleSkinKey);
		else if (this._data.ErrorTitleMsg)
			title = this._data.ErrorTitleMsg;
		this._fatalErrorTitle.set('text', title);
		if (!title)
			this._fatalErrorTitle.hide();
		
		var detail = '';
		if (this._data.ErrorDetailSkinKey)
			detail = Skin.getInstance().getPlatformStyle(this._data.ErrorDetailSkinKey, '');
		else if (this._data.ErrorDetailMsg)
			detail = this._data.ErrorDetailMsg;
		this._fatalErrorDescription.set('text', detail);
		if (!detail)
			this._fatalErrorDescription.hide();
		
		this._doLayout();
	},

	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});

// ****************************************************************************
// ****************************************************************************
// Constants used to register and identify custom PureMVC events
// ****************************************************************************
// ****************************************************************************

