// ----------------------------------------------------------------------------
// This View handles the GallerySlider
// ----------------------------------------------------------------------------
GallerySlider = new Class(
{
	Extends : DialogView,

	// ************************************************************************
	// ************************************************************************
	//     MEMBER VARIABLES
	// ************************************************************************
	// ************************************************************************

	// ********** Add variables for each data field here **********

	// ************************************************************************
	// ************************************************************************
	//     LIST OF PLUGIN ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************
	
	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	
	listJavascriptAssets : function()
	{
		return	[
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'frameworks/jQuery/plugins/galleryslider/lightgallery.js',
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'frameworks/jQuery/plugins/galleryslider/lg-fullscreen.js',
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'frameworks/jQuery/plugins/galleryslider/lg-thumbnail.js',
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'frameworks/jQuery/plugins/galleryslider/lg-video.js',
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'frameworks/jQuery/plugins/galleryslider/lg-autoplay.js',
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'frameworks/jQuery/plugins/galleryslider/lg-zoom.js',
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'frameworks/jQuery/plugins/galleryslider/lg-hash.js',
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'frameworks/jQuery/plugins/galleryslider/lg-pager.js'
				];
	},

	// ------------------------------------------------------------------------
	// This function returns the list of plug-ins to dynamically load for this component
	//
	// @return {String[]} - the array of plug-ins to load.
	// ------------------------------------------------------------------------

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('GallerySlider', this);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theDialogData (Object) - Contains argument data for the dialog
	// ------------------------------------------------------------------------
	init : function(theBasePath, theDialogData)
    {		
		this.parent(theDialogData,
		{
			basePath : theBasePath,
			title:  '',				// Need to set this in onContentLoaded so it will pick up translated title from the component skin
			width:  0,
			height: 0,
			isModal: true,
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});
	},
	
 	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------

	_onContentLoaded : function()
	{
		this.parent();
		var src_string = Skin.getInstance().getProductStyle("GallerySlider_Sources")
		var src_array = src_string.split(',');
		var thumb_string = Skin.getInstance().getProductStyle("GallerySlider_Thumbs")
		var thumb_array = thumb_string.split(',');
		var caption_string = Skin.getInstance().getProductStyle("GallerySlider_Captions")
		var caption_array = caption_string.split(',');
		var finalArray = [];
		for (var j=0;j<src_array.length;j++)
		{

			var destArray = {src: '',thumb:'',subHtml:''};
			destArray.src = src_array[j];
			destArray.thumb = thumb_array[j];
			destArray.subHtml = caption_array[j]
			finalArray.push(destArray);
		}
		jQuery(this).lightGallery({
	    	fullScreen: false,
	    	closable: false,
	        dynamic: true,
	        dynamicEl: finalArray
	    });
		this._show();
		this._closeDelay.delay(100, this);
	},

	_closeDelay : function() 
	{
	    this._closeBtn = document.getElement('#lg-close-btn');
	    this._closeBtn.addEvent('click', this.onClose.bind(this));
	},

	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});
