// ----------------------------------------------------------------------------
// This View handles the GenericTabPanel component
// ----------------------------------------------------------------------------
GenericTabPanel = new Class(
{
	Extends : DynamicComponent,
	
	// ************************************************************************
	// ************************************************************************
	//     MEMBER VARIABLES
	// ************************************************************************
	// ************************************************************************	
	
	_tabRootElement : null,
	_tabTitle : null,
	_tabClose : null,
		
	_minResultsWidth : null,
	_minResultsHeight : null,
	_tabPanelWidth : 0,					// (Int)
	_tabPanelHeight : 0,				// (Int)

	// ************************************************************************
	// ************************************************************************
	//     LIST OF PLUGIN ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	hasSkinCoreAsset : function(){return true;},
	// If hasSkinLangAsset is true then _onChangeLanguage() is called when user changes languages (after language resources are loaded)
	hasSkinLangAsset : function(){return true;},

	// ------------------------------------------------------------------------
	// These functions return the list of plug-in assets to dynamically load for this component
	// ------------------------------------------------------------------------
	listJavascriptAssets : function(){return [];},
	listCssAssets : function(){return [];},
	
	// ------------------------------------------------------------------------
	// This function returns a path to an optional html asset to load for this component
	// ------------------------------------------------------------------------
	listHtmlAsset : function(){return 'GenericTabPanel.html';},

	// ************************************************************************
	// ************************************************************************
	//     MEDIATOR FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// This function returns the list of notifications to register this view for.
	//
	// @return {String[]} - the array of notification names to act upon.
	// ------------------------------------------------------------------------
    listNotificationInterests : function()
    {
		var theArray = this.parent().append
		(
			[
				ApplicationFacade.APPLICATION_RESIZED
			]
		);
        return theArray;
    },

	// ------------------------------------------------------------------------
	// This function is called to handle all notifications listed in the 
	// listNotificationInterests function
	//
	// Arguments:
	//     notification (Notification) - The notification to act upon
	// ------------------------------------------------------------------------
    handleNotification : function(notification)
    {
		switch(notification.getName())
		{
			case ApplicationFacade.APPLICATION_RESIZED:
				this._onResize();
				break;
			default:
				this.parent(notification);
				break;
		}
    },

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('GenericTabPanel', this);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theComponentData (Object) - Contains argument data for the component
	// ------------------------------------------------------------------------
	init : function(theBasePath, theComponentData)
    {		
		this.parent(theComponentData,
		{
			basePath : theBasePath,
			title:  '',				// Need to set this in onContentLoaded so it will pick up translated title from the component skin
			width: 300,
			injectLocation: theComponentData.options.tabPanelElement,
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{		
		this.parent();	
		
		this._tabRootElement = this._data.options.tabPanelElement.getElement('#GenericTabPanel_Content');
		this._minResultsWidth = this.options.width;
		this._minResultsHeight = this.options.height;
		
		Elements.from(
		'															\
			<div class="tabTitle">Title</div>						\
			<div class="tabClose"></div>							\
		').inject(this._tabRootElement);
		
		this._tabTitle = this._tabRootElement.getElement('.tabTitle');
		this._tabClose = this._tabRootElement.getElement('.tabClose');
		this._tabClose = new SpriteButton(this._tabClose);	
		if (this._tabClose)
			this._tabClose.addEvent(SpriteButton.CLICK, this._onClose.bind(this));

		this._onChangeLanguage();		
	},
	
	// ------------------------------------------------------------------------
	// Called by DynamicComponent class after the component language skin files
	// have been loaded when the user changes the language.  Here is where we
	// set up or change language based skin resources.
	// ------------------------------------------------------------------------
	_onChangeLanguage : function()
    {
		var theSprite = Skin.getInstance().getPath(['ResultsViewBtnClose','LeftPanelBtnClose'], '');
		if (theSprite != '')
			this._tabClose.setImage(theSprite+CacheMgr.getInstance().getResourceCacheArg('RelId','&'));
		else
			this._tabClose.setGlyph('glyphicon-remove');
		this._tabTitle.set('text', Skin.getInstance().get('GenericTabPanelTitle','No Title in Skin'));
	},

	// ------------------------------------------------------------------------
	// Event handler for when the [x] close box is clicked
	// ------------------------------------------------------------------------
	_onClose : function()
	{
		this._data.options.close();
	},
	
	// ------------------------------------------------------------------------
	// Called by SlideInTabView when window is resized
	// ------------------------------------------------------------------------
	_onResize : function()
	{	
	},

	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});

// ****************************************************************************
// ****************************************************************************
// Constants used 
// ****************************************************************************
// ****************************************************************************

