// ----------------------------------------------------------------------------
// This View handles the TpodShareEmail Dialog
// ----------------------------------------------------------------------------
TpodShareEmail = new Class(
{
	Extends : DialogView,

	// ************************************************************************
	// ************************************************************************
	//     LIST OF ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************
	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	hasSkinCoreAsset : function(){return true;},
	// If hasSkinLangAsset is true then _onChangeLanguage() is called when user changes languages (after language resources are loaded)
	hasSkinLangAsset : function(){return true;},
	// ------------------------------------------------------------------------
	// These functions return the list of plug-in assets to dynamically load for this component
	// ------------------------------------------------------------------------
	listJavascriptAssets : function()
	{
		return	[
					BASE_PATH_TO_APP + RELATIVE_PATH_TO_CODE + 'frameworks/jQuery/plugins/jquery.md5.js',
				];
	},

	// ************************************************************************
	// ************************************************************************
	//     MEDIATOR FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ************************************************************************
	// ************************************************************************
	//     MEMBERS VARIABLES
	// ************************************************************************
	// ************************************************************************	
	_appState : null,
	// ********** Add variables for each data field here **********
	
	_emailPanel : null,
	_emailPanelToEmail : null,
	_emailPanelNotes : null,

	_sentPanel : null,
	
	_buttonContainer : null,
	_buttonActionCenter : null,

	_sendBtn : null,
	_sendSpriteImage : null,
	_emailPanelLinkContainer : null,
	
	_shareLinkType : 'study',
	
	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('TpodShareEmail', this);
		this._appState = Facade.getInstance().retrieveProxy(AppState.NAME);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theDialogData (Object) - Contains argument data for the dialog
	// ------------------------------------------------------------------------
	init : function(theBasePath, theDialogData)
    {		
		this.parent(theDialogData,
		{
			basePath : theBasePath,
			title:  '',				// Need to set this in onContentLoaded so it will pick up translated title from the component skin
			width:  580,
			height: 350,
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{
		this.parent();
		this._popUpWindow.setTitle(Skin.getInstance().get('TpodShareEmailTitle', 'Email'));
		this._descElement = this._widgetRootElement.getElement('#SamsInstantSavingsDetail_desc');
		
		this._show();
	},

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{		
		this.parent();

		this._emailPanel = this._widgetRootElement.getElement('#TpodShareEmail_EmailPanel');
		this._sentPanel = this._widgetRootElement.getElement('#TpodShareEmail_SentPanel');
		this._buttonContainer = this._widgetRootElement.getElement('#TpodShareEmail_button_container');
		this._buttonActionCenter = this._widgetRootElement.getElement('#TpodShareEmail_button_container .actionCenter');
		
		this._sendBtn = this._widgetRootElement.getElement('#TpodShareEmail_button_send');
		this._sendBtn =   new SpriteButton(this._sendBtn);
		this._widgetRootElement.getElement('#TpodShareEmail_button_send').set('html', Skin.getInstance().get('TpodShareEmailSend', 'Submit'));		
	
		this._emailPanelToEmail = this._widgetRootElement.getElement('#TpodShareEmail_EmailPanel_ToEmailField');
		this._emailPanelNotes = this._widgetRootElement.getElement('#TpodShareEmail_EmailPanel_NotesField');
		
		this._emailPanelLinkContainer = this._widgetRootElement.getElement('#TpodShareEmail_EmailPanel_Link_Container');
		var theEmailPanelShareImage = this._widgetRootElement.getElement('#TpodShareEmail_EmailPanel_Image');
		var theEmailPanelShareImageContainer = this._widgetRootElement.getElement('#TpodShareEmail_EmailPanel_ImgContainer');
		theEmailPanelShareImageContainer.hide();
		
		// Load the pre-set email content
		var theToEmailField = this._emailPanel.getElement('#TpodShareEmail_EmailPanel_ToEmailField');
		var theToEmailValue = Skin.getInstance().get('TpodShareEmailRequired', 'required');
		theToEmailField.value = theToEmailValue;
		theToEmailField.onfocus = function(){this.className = 'TpodShareEmail_EmailPanel_Focused'; this.focus(); if (this.value == theToEmailValue) {this.value = '';};};
		theToEmailField.onblur = function(){if (this.value != '' && this.value != theToEmailValue ) {this.className = 'TpodShareEmail_EmailPanel_Focused'} else {this.className = 'TpodShareEmail_EmailPanel_Unfocused'} ; if (this.value == '') {this.value = theToEmailValue;};};
		
		var theNotesField = this._emailPanel.getElement('#TpodShareEmail_EmailPanel_NotesField');
		var theNotesValue = '';
		theNotesField.value = theNotesValue;
		theNotesField.onfocus = function(){this.className = 'TpodShareEmail_EmailPanel_Focused'; this.focus(); if (this.value == theNotesValue) {this.value = '';};};
		theNotesField.onblur = function(){if (this.value != '' && this.value != theNotesValue ) {this.className = 'TpodShareEmail_EmailPanel_Focused'} else {this.className = 'TpodShareEmail_EmailPanel_Unfocused'} ; if (this.value == '') {this.value = theNotesValue;};};

		var theLabelElement = this._emailPanel.getElement('#TpodShareEmail_EmailPanel_ToEmailLabel');
		var theLabel = Skin.getInstance().get('TpodShareEmailRecipients', 'Recipient') + ':';
		theLabelElement.set('html', theLabel);
		theLabelElement = this._emailPanel.getElement('#TpodShareEmail_EmailPanel_MessageLabel');
		theLabel = Skin.getInstance().get('TpodShareEmailMessage', 'Message') + ':';
		theLabelElement.set('html', theLabel);
		theLabelElement = this._sentPanel.getElement('#TpodShareEmail_SentPanel_ThanksLabel');
		theLabel = Skin.getInstance().get('TpodShareEmailThanks', 'Thank You!');
		theLabelElement.set('html', theLabel);
		theLabelElement = this._sentPanel.getElement('#TpodShareEmail_SentPanel_EamilSentLabel');
				
		var theLinkField = this._emailPanel.getElement('#TpodShareEmail_EmailPanel_Link');
		this._shareLinkType = Skin.getInstance().get('TpodStudyShareEmailLinkType', 'study');
		if (this._shareLinkType == 'study')
		{
			theLabel = Skin.getInstance().get('TpodShareEmailEmailStudySent', 'An email containing a link to your presentatin has been sent to the following recipient(s):');
			theLabelElement.set('html', theLabel);
			
			this._dataUrlArray = this._data.Url;
			if (typeOf(this._data.Url) == 'array')
			{
				this._dataUrlArray = this._data.Url;
			}
			else
			{
				this._dataUrlArray = new Array();
				this._dataUrlArray.push(this._data.Url);
			}
			if (this._data.Url)
			{
				var theLinks = '';
				this._dataUrlArray.each(function(item, index)
				{
					if (typeOf(item) == 'object')
						theLinks += '<a href="' + item.url + '">' + item.title + '</a><br>';
					else
						theLinks += item + '<br>';
				}.bind(this));
				theLinkField.set('html', theLinks);
			}
			else
				this._emailPanelLinkContainer.hide();
		}
		else
		{
			theLabel = Skin.getInstance().get('TpodShareEmailEmailPdfSent', 'Your presentation is being generated.  Once your presentation is complete an email containing a link to the presentation will be sent to you and the following recipient(s):');
			theLabelElement.set('html', theLabel);
			this._emailPanelLinkContainer.hide();
		}
			
		this._sendBtn.addEvent('click', this._onClickSend.bind(this));
		this._sendBtn.mooTouchAdd({'click':true});
	
		this._emailPanelToEmail.addEvent('focus', this._focusToEmailField.bind(this));
		this._emailPanelNotes.addEvent('focus', this._focusNotesField.bind(this));

		this._buttonContainer.show();		
		this._onClickEmail();
		
		this._popUpWindow.setTitle(Skin.getInstance().get('TpodShareEmailTitle', 'Share Presentation'));
		
		this._show();
		// Dialog had to be visible before we arrange footer dialog buttons
		this._doButtonContainerLayout();
	},
	
	// ************************************************************************
	// ************************************************************************
	//
	// ********** Add Custom Functions and Event Handlers here **********
	//
	// ************************************************************************
	// ************************************************************************
	
	// ------------------------------------------------------------------------
	// Button click event handlers
	// ------------------------------------------------------------------------

	_onClickEmail : function(e)
	{
		this._sendBtn.show();
		this._sentPanel.hide();
		this._emailPanel.show();
	},

	_focusToEmailField : function ()
	{
		if (Browser.Platform.mobile || Browser.Platform.tablet)
		{
			this._emailPanelToEmail.set('value', '');	// For Mobile and IPads, clear text when it receives focus (otherwise it is a pain to modify with the mobile keyboard)
			this._emailPanelToEmail.focus();
		}
	},

	_focusNotesField : function ()
	{
		if (Browser.Platform.mobile || Browser.Platform.tablet)
		{
			this._emailPanelNotes.set('value', '');	// For Mobile and IPads, clear text when it receives focus (otherwise it is a pain to modify with the mobile keyboard)
			this._emailPanelNotes.focus();
		}
	},
		
	_onClickSend : function(e)
	{
		var str = '';			// Part of md5 hash algorithm
		var linkprefix = Skin.getInstance().get('TpodShareEmailLinkPrefix','');
		this._emailElement = this._widgetRootElement.getElement('#TpodShareEmail_EmailPanel');
		str += 'c2k.';			// Part of md5 hash algorithm
		
		var fromEmail = this._appState.get(AppState.currentUserLogin).trim();
		str += fromEmail;		// Part of md5 hash algorithm
		
		var element = this._emailElement.getElementById('TpodShareEmail_EmailPanel_ToEmailField');
		var toEmail = element.value.trim();
		str += toEmail;			// Part of md5 hash algorithm
		var element = this._emailElement.getElementById('TpodShareEmail_EmailPanel_NotesField');
		var notes = encodeURIComponent(element.value);
		str += element.value;			// Part of md5 hash algorithm
		
		if (this._shareLinkType == 'study')
		{
			if (this._dataUrlArray)
			{
				if (this._dataUrlArray.length == 1)
				{
					notes += '<br /><br /><table align="center"><tbody><tr>';
					str += '<br /><br /><table align="center"><tbody><tr>';
					notes += '<td align="center">';
					str += '<td align="center">';
					notes += '<a href="' + escape(this._dataUrlArray[0]) + '" target="_blank"><img src="' + escape(this._data.ShareImageUrl) + '"  border="0" style="display: block; max-height: 300px; max-width: 580px; text-align: center;"></a></td></tr></tbody></table>';
					str += '<a href="' + this._dataUrlArray[0] +  '" target="_blank"><img src="' + this._data.ShareImageUrl + '"  border="0" style="display: block; max-height: 300px; max-width: 580px; text-align: center;"></a></td></tr></tbody></table>';		
				}
				
				this._dataUrlArray.each(function(item, index)
				{
					if (typeof(item) == 'object')
					{
						notes += '<br /><span style="color:#1155cc;font-family:Georgia,serif;font-size:14px;">' + linkprefix + '</span><a href="' + escape(item.url) + '" target="_blank">' + escape(item.title) + '</a>';
						str +=   '<br /><span style="color:#1155cc;font-family:Georgia,serif;font-size:14px;">' + linkprefix + '</span><a href="' + item.url + '" target="_blank">' + item.title + '</a>';						
					}
					else
					{
						notes += '<br /><span style="color:#1155cc;font-family:Georgia,serif;font-size:14px;">' + linkprefix + '</span><a href="' + escape(item) + '" target="_blank">' + escape(item) + '</a>';
						str +=   '<br /><span style="color:#1155cc;font-family:Georgia,serif;font-size:14px;">' + linkprefix + '</span><a href="' + item + '" target="_blank">' + item + '</a>';	
					}
				}.bind(this));
			}				
		}
		else
		{
			var pdfServiceUrl = Skin.getInstance().get('PdfServiceUrl', 'http://pdf.dirxion.com');
			var exportPdfLink = pdfServiceUrl + '/tmp/tpod/**PDFEXPORTOUTPUTNAME**';
			notes += '<br /><span style="color:#1155cc;font-family:Georgia,serif;font-size:14px;">' + linkprefix + '</span><a href="' + escape(exportPdfLink) + '" target="_blank">' + escape(exportPdfLink) + '</a>';
			str +=   '<br /><span style="color:#1155cc;font-family:Georgia,serif;font-size:14px;">' + linkprefix + '</span><a href="' + exportPdfLink + '" target="_blank">' + exportPdfLink + '</a>';	
		}
		
		this._sendBtn.hide();
		
		var theLanguageList, theLanguageIndex, theLanguageCode, theCompanyCode, theReplyToAddr;
		theLanguageList = this._appState.get(currentLanguageList);
		theLanguageIndex = this._appState.get(currentLanguageIndex);
		theLanguageCode = theLanguageList.getLanguageCode(theLanguageIndex);
		theCompanyCode = Skin.getInstance().get("DefaultCompanyCode");
		theReplyToAddr = Skin.getInstance().get("TpodShareEmailReplyAddress");
		var postBody = 'CompanyCode='+theCompanyCode+'&lang='+theLanguageCode+'&fromEmail='+encodeURIComponent(fromEmail)+'&toEmail='+encodeURIComponent(toEmail)+'&notes='+notes+'&LinkType='+this._shareLinkType+'&ReplyTo='+encodeURIComponent(theReplyToAddr);

		if (USING_SHARED_CODE)
		{
			postBody += '&UncDataPath=' + UNC_PATH_TO_DATA;
			postBody += '&UrlDataPath=' + REMOTE_PATH_TO_DATA;
			postBody += '&UrlRootPath=' + BASE_PATH_TO_APP;
		}
		// Hash time with the body and a key.  On the server side, we perform a similar hash to validate.  If it validates
		// then we further verify that theTime is within some timeout period to prevent denial of service email floods
		// using one know good email call over and over.
		var a1 = jQuery.md5(str);
		postBody += '&a1=' + a1;

		var theServicePath = this._getBasePath();
		if (window.cordova)
			theServicePath = REMOTE_PATH_TO_SERVICES + this._getBasePath();

		if (Browser.ie && Browser.version < 10)
		{
			var xdr = new XDomainRequest();
			xdr.onerror = function(){Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:'Login Failed!', title:'Login'});};
			xdr.ontimeout = function(){Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:'Login Failed!', title:'Login'});};
			xdr.onprogress = function(){};
			xdr.onload = function()
			{
				this._widgetRootElement.getElement('#TpodShareEmail_SentPanel_ToEmail').set('html', toEmail);
				if (this._shareLinkType == 'pdf')
				{
					var parsed_json = JSON.decode(xdr.responseText); // covert JSON string to JSON object
					this._emailTpodStudy(parsed_json.subject,parsed_json.message,toEmail,fromEmail,theReplyToAddr);
				}
				this._emailPanel.hide();
				this._sentPanel.show();	
			}.bind(this);
			//Requests must be targeted to the same scheme as the hosting page (http->http and https->https)
			xdr.open("post", theServicePath + 'TpodServiceEmail.php'+CacheMgr.getInstance().getResourceCacheArg('RelId','?'));
			xdr.post(postBody);
		}
		else
		{
			var myHTMLRequest = new Request.CORS(
			{
				url: theServicePath + 'TpodServiceEmail.php'+CacheMgr.getInstance().getResourceCacheArg('RelId','?'),
				format: 'json', // string format passed back from service
				method: 'post',  // request type
				onSuccess:function(response_text)
				{
					this._widgetRootElement.getElement('#TpodShareEmail_SentPanel_ToEmail').set('html', toEmail);
					if (this._shareLinkType == 'pdf')
					{
						var parsed_json = JSON.decode(response_text); // covert JSON string to JSON object
						this._emailTpodStudy(parsed_json.subject,parsed_json.message,toEmail,fromEmail,theReplyToAddr);
					}
					this._emailPanel.hide();
					this._sentPanel.show();					
				}.bind(this),
				onFailure: function(xhr)
				{
					Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:'Email Failed!', title:'Email'});
					return;
				}.bind(this)
			}).post(postBody);
		}
		
	},
	
	_emailTpodStudy : function (subject,message,toEmail,fromEmail,theReplyToAddr)
	{
		this._book = this._appState.get(currentBook);
		var studyList = this._appState.get(AppState.tpodCurrentStudyList);
		var studyListObj = this._appState.get(AppState.tpodCurrentStudyListObj);
		var studyName = studyListObj.title;
		var theStudyHash = null;
		for (var i=0;i<studyList.length;i++)
		{
			if (studyList[i].StudyName == studyName)
			{
				theStudyHash = studyList[i].StudyHash;
				break;
			}
		}
		var studyType = Skin.getInstance().getBoolean('TpodLite', false, Skin.PLATFORM_STYLE) == true ?	'TPODLite-Study' : 'TPOD-Study';
		var theMostCommonPageDimension = this._book.sections[0].getTpodSectionDimension();
		var htmlPageSizeStr = theMostCommonPageDimension.width + 'px*' + theMostCommonPageDimension.height + 'px';
		var resizePageEnabled = Skin.getInstance().getBoolean('TpodExportResizeEnabled', false) ? true : false;
		var pageDiffSlush = Skin.getInstance().getNumber('TpodExportResizeDiffPct', '15');
		var pdfEntirePdfChecked = 1;
		var pdfCheckCover = 0;
		
		// Set this._pdfConvertedPageRangeRequest to export the entire study
		var pdfExportPageRangeLimit = 0;		// No page range limit if downloading entire pdf
		var pdfStatusTotalCount = studyListObj.sections[0].pages.length;
		var pdfPageRangeRequest = "\"0\"-\"" + (pdfStatusTotalCount-1).toString() + "\"";
		var pdfSaveName = this._book.title;
		// File name cannot have the following characters / \ : * ? " < >  | %
		var myPattern1 = /[\/\\\:\*\?\"\<\>\|\%\.\ ]/g;		// Filter out these special characters as well as periods and spaces (and replace with underscores)
		pdfSaveName = pdfSaveName.replace(myPattern1, "_");
		pdfSaveName += ".pdf";
			
		var pdfServiceUrl = Skin.getInstance().get('PdfServiceUrl', 'http://pdf.dirxion.com');
		if (Browser.ie && Browser.version < 11)
		{
			var theUrl = pdfServiceUrl + '/ServicePdfRequest.php' + 
						 '?TpodStudy=' + encodeURIComponent(theStudyHash) + 
						 '&Arg=' + encodeURIComponent(pdfPageRangeRequest) +
						 '&SizeStr=' + encodeURIComponent(htmlPageSizeStr) +
						 '&PageDiffSlush=' + encodeURIComponent(pageDiffSlush) + 
						 '&ResizeFlag=' + encodeURIComponent(resizePageEnabled) +
						 '&EmailMessage=' + encodeURIComponent(message) +
						 '&EmailTo=' + encodeURIComponent(toEmail) +
						 '&EmailFrom=' + encodeURIComponent(fromEmail) +
						 '&Subject=' + encodeURIComponent(subject) +
						 '&ReplyTo=' + encodeURIComponent(theReplyToAddr) +
						 '&StudyType=' + encodeURIComponent(studyType);
						 				
			var xdr = new XDomainRequest();
			xdr.onerror = function(){Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:"ServicePdfRequest Error"});};
			xdr.ontimeout = function(){Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:"ServicePdfRequest Timeout"});};
			xdr.onprogress = function(){};
			xdr.onload = function(){}.bind(this);
			xdr.open("post", theUrl + '&' + String.uniqueID());
			xdr.send();
		}
		else
		{
			request = new Request.CORS(
			{
				method: 'post',
				noCache: true,
				url: pdfServiceUrl + '/ServicePdfRequest.php',
				data: 'TpodStudy=' + theStudyHash + 
					  '&Arg=' + pdfPageRangeRequest + 
					  '&SizeStr=' + htmlPageSizeStr + 
					  '&PageDiffSlush=' + pageDiffSlush + 
					  '&ResizeFlag=' + resizePageEnabled +
					  '&EmailMessage=' + message +
					  '&EmailTo=' + toEmail +
					  '&EmailFrom=' + fromEmail +
					  '&Subject=' + subject +
					  '&ReplyTo=' + theReplyToAddr +
					  '&StudyType=' + studyType,
				onSuccess: function(responseText, responseXml)
				{					
				}.bind(this),
				onFailure: function(obj)
				{
				}.bind(this)
			});
			request.send();
		}
	},

	_doButtonContainerLayout : function()
	{
		// Set the container left to zero before measuring to make sure buttons will all fit side by side without wrapping
		this._buttonActionCenter.setStyle('left',0);
		var theParentSize = this._buttonContainer.measure(function(){return this.getSize();});
		var theSize = this._buttonActionCenter.measure(function(){return this.getSize();});
		this._buttonActionCenter.setStyle('left',(theParentSize.x/2) - (theSize.x/2));
	},
	
	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});
